extensions [table array]

globals [ MIN-LOW MAX-LOW MIN-MEDIUM MAX-MEDIUM MIN-HIGH MAX-HIGH IND-KNOW-MIN IND-KNOW-MAX probIND
  groupKnowledge groupPlannedExtraction resourceStockSize resourceStockBeforeExtraction totalExtraction numberUsersCom resourceRegrowth
  confidenceSum regrowthTable optimalExtractionTable stockSizeBeforeGrowth numSpeakers numGroupPlannedExtraction numPlannedExtraction dominantConfidence dominantSocialSkill endOfPlay
  almostZero domConfSpeaker confSpeakerBefore autoSeed numberUsers initResourceStockSize dominantSocialSpeaker
  numSocPref numSocSkills endOfGame
  cooperation cooperationHistory cooperationCount coopPower efficiency
  sumStocksizeBeforeGrowth sumTotalExtraction sumEfficiency sumGroupKnowledge
  medianStocksizeBG sdStocksizeBG stockSizeList
  sdEfficiency medianEfficiency efficiencyList
  meanTotalExtraction medianTotalExtraction sdTotalExtraction totalExtractionList
  sdGroupKnowledge medianGroupKnowledge groupKnowledgeList

  meanStocksizeBG meanEfficiency meanGroupKnowledge time-of-depletion depleted
  normalized-extraction meanTrust sdTrust medianTrust meanConfidence sdConfidence medianConfidence meanIndKnow sdIndKnow medianIndKnow
  gini gini-approx overExploit_cnt optimal_cnt underExploit_cnt overexploitingGroup underexploitingGroup optimalGroup
  individualKnowledge1 individualKnowledge2 individualKnowledge3 individualKnowledge4
  sk_init_case
  optimal overExpl underExpl
  ]

breed [ users  user ]

users-own [
  initSocSkills                          ; for testing initialisations
  socialSkills
  speaker
  socialPreferences
  individualKnowledge                   ;; optimal perceived stock size
  trust
  confidenceKnowledge
  plannedExtraction
  actualExtraction
  accumulatedExtraction
  deviation
  exp-type
]

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; SETUP
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to setup
  clear-all
  set autoSeed new-seed
  ifelse (autoRandomSeed)
  [ random-seed autoSeed ]
  [ random-seed manualSeed ]

; for testing
set sk_init_case 0    ; initial distribution of social skills, used for testing the initialisation

;; Constants
set MIN-LOW 0.06
set MAX-LOW 0.34
set MIN-MEDIUM 0.36
set MAX-MEDIUM 0.64
set MIN-HIGH 0.66
set MAX-HIGH 0.94

set probIND 0.8

set optimal false
set overExpl false
set underExpl false

if (init_knowledge_distr = "extreme-optimal-25-29") [
  set IND-KNOW-MIN 25
  set IND-KNOW-MAX 29 ]
if (init_knowledge_distr = "weak-optimal-20-34") [
  set IND-KNOW-MIN 20
  set IND-KNOW-MAX 34 ]
if (init_knowledge_distr = "largerRange-15-39") [
  set IND-KNOW-MIN 15
  set IND-KNOW-MAX 39 ]
if (init_knowledge_distr = "completeRange-5-49") [
  set IND-KNOW-MIN 5
  set IND-KNOW-MAX 49 ]
if (init_knowledge_distr = "underExpl-skewed-25-44") [
  set IND-KNOW-MIN 25
  set IND-KNOW-MAX 44 ]
if (init_knowledge_distr = "overExpl-skewed-10-29") [
  set IND-KNOW-MIN 10
  set IND-KNOW-MAX 29 ]

;; Globals
set initResourceStockSize 50
set resourceStockSize initResourceStockSize
set endOfGame 13            ;; 14 time steps
create-regrowth-table
create-optimalClaim-table
set dominantConfidence 0
set dominantSocialSkill 0
set numberUsersCom 0
set almostZero 0.05
set numberUsers 4
set cooperationHistory 0;
set cooperationCount 0;
set cooperation true;
set efficiency 0;

set sumStocksizeBeforeGrowth 0;
set sumTotalExtraction 0;
set sumEfficiency 0;
set sumGroupKnowledge 0;
set meanStocksizeBG 0;
set meanEfficiency 0;
set meanGroupKnowledge 0;
set meanTotalExtraction 0

set medianStocksizeBG 0
set sdStocksizeBG 0
set stockSizeList []
set sdEfficiency 0
set medianEfficiency 0
set efficiencyList []
set sdGroupKnowledge 0
set medianGroupKnowledge 0
set groupKnowledgeList []
set medianTotalExtraction 0
set sdTotalExtraction 0
set totalExtractionList []

set overexploitingGroup 0;
set underexploitingGroup 0;
set optimalGroup 0;
set overExploit_cnt 0;
set underExploit_cnt 0;
set optimal_cnt 0;

set time-of-depletion 0
set depleted false

ask patches [ set pcolor 38 ]
color-pond

;; Users
set numSocPref 0
set numSocSkills 0
create-users numberUsers [
  setxy random-xcor random-ycor
  set color orange
  set size 3
  set shape "person"
  layout-circle turtles 5                      ;; users have a fixed location, circle
  init-user
]
init-group-composition
init-experiment
determine-speakers
set confSpeakerBefore -1
reset-ticks
end

;Initalises the agent attributes
to init-user
  ;; initialises the social preferences of an agent, social preferences == 1 -> equal sharing preferences
  set exp-type "not-experimenting-type-for-now"
  if (socialPreferences_distribution = "noone") [ set socialPreferences 0 ]
  if (socialPreferences_distribution = "all") [ set socialPreferences 1 ]
  if (socialPreferences_distribution = "random") [ set socialPreferences random 2 ]   ;; only for calibration purposes
  if (socialPreferences_distribution = "75%") [
    ifelse (numSocPref < floor(numberUsers * 0.75))
    [ set socialPreferences 1
      set numSocPref numSocPref + 1 ]
    [ set socialPreferences 0 ]]
  if (socialPreferences_distribution = "50%") [
    ifelse (numSocPref < floor(numberUsers * 0.5))
    [ set socialPreferences 1
      set numSocPref numSocPref + 1 ]
    [ set socialPreferences 0 ]]
  if (socialPreferences_distribution = "25%")[
   ifelse (numSocPref < floor(numberUsers * 0.25))
   [ set socialPreferences 1
     set numSocPref numSocPref + 1 ]
   [ set socialPreferences 0 ]]
  ;show (sentence "social preferences init: " socialPreference_distribution " with " socialPreferences)

;; initialises individualKnowledge of an agent based on the Interface-selection
  set individualKnowledge getRandomKnowledge
  ;show (sentence "individualKnowledge init: with " individualKnowledge)
end

;; Initialises the individual agent attributes based on group composition distribution given in the interface
to init-group-composition
  init-group-socialSkills
  init-group-trust
  init-group-confidence
end


;; ## Function only used for the scenario experiments ##
;;Initialises each agent specifically for the scenario experiment
to init-experiment
if (experiment) [
  let userInitCnt 0
  let userInitUnInfSpeakHigh 0 ; counts connected to interface
  let userInitUnInfSpeakLow 0
  ask turtles [
    set trust getRandomFloat MIN-HIGH MAX-HIGH

    ifelse (userInitCnt < numInformed) [
      ;show (word "informed agent - counter = "  userInitCnt)
      set userInitCnt userInitCnt + 1
      set individualKnowledge 25 + random (29 + 1 - 25)  ; extreme optimal - random value between IND-KNOW-MIN <= x < IND-KNOW-MAX + 1, the function random does not take the max value into account, therefore the +1
      set exp-type "informed"
      ;set trust getRandomFloat MIN-HIGH MAX-HIGH
      set socialPreferences 0
      set speaker 1
      ifelse (confInformed = "high")
        [ set confidenceKnowledge 0.8 ]
        [ set confidenceKnowledge 0.2 ]
    ];else uninformed agents
    [ ;show (word "unformed agent")
      set userInitCnt userInitCnt + 1
      set exp-type "uninformed"

      ifelse (userInitUnInfSpeakHigh < numUnInfSpeakHigh) [
        set userInitUnInfSpeakHigh userInitUnInfSpeakHigh + 1
        set individualKnowledge 5 + random (24 + 1 - 5) ; 30 + random (49 + 1 - 30)
        ;set trust getRandomFloat MIN-HIGH MAX-HIGH
        set socialPreferences 1
        set confidenceKnowledge 0.8
        set speaker 1 ]
      [
        ifelse (userInitUnInfSpeakLow < numUnInfSpeakLow) [
         set userInitUnInfSpeakLow userInitUnInfSpeakLow + 1
         set individualKnowledge  5 + random (24 + 1 - 5) ; 30 + random (49 + 1 - 30)
         ;set trust getRandomFloat MIN-HIGH MAX-HIGH
         set socialPreferences 1
         set confidenceKnowledge 0.2
         set speaker 1 ]

         ; all the rest of the uninformed should be set the following and not speak
         [
          set individualKnowledge 5 + random (24 + 1 - 5) ; 30 + random (49 + 1 - 30)
          ;set trust getRandomFloat MIN-HIGH MAX-HIGH
          set socialPreferences 1
          set confidenceKnowledge 0.2
          set speaker 0 ]
      ]
    ]
    ;show (word "knowl: " individualKnowledge " ck: " confidenceKnowledge " sk:" socialSkills "speak: " speaker) ;]
  ]]
end

;; initialises the social skills of an agent based on interface selection
;; social skills reflects the probability with which an agent speaks up, values 0 and 1 are included
to init-group-socialSkills
  ifelse (socialSkills_distribution = "noone") [ ask users [ set socialSkills 0 ] ]
  [ ifelse (socialSkills_distribution = "random") [ ask users [ set socialSkills (random 11) / 10 ]]
    [ ifelse (socialSkills_distribution = "all_high") [ ask users [ set socialSkills getRandomFloat MIN-HIGH MAX-HIGH ]]
      [ ifelse (socialSkills_distribution = "all_low") [ ask users [ set socialSkills getRandomFloat MIN-LOW MAX-LOW]]

  [ ; heterogeneous groups
    let high_cnt 0
    let medium_cnt 0
    let low_cnt 0

    if (socialSkills_distribution = "75-0-25_lmh") [
      set low_cnt round (0.75 * numberUsers)
      set medium_cnt 0
      set high_cnt round (0.25 * numberUsers)
    ]
    if (socialSkills_distribution = "50-0-50_lmh") [
      set low_cnt round (0.5 * numberUsers)
      set medium_cnt 0
      set high_cnt round (0.5 * numberUsers)
    ]
    if (socialSkills_distribution = "25-0-75_lmh") [
      set low_cnt round (0.25 * numberUsers)
      set medium_cnt 0
      set high_cnt round (0.75 * numberUsers)
    ]

    ;;Based on the number of agents with high and low social skills the agents are now initialised with these levels of social skills
    ask users [
      ifelse (high_cnt > 0) [
        set socialSkills getRandomFloat MIN-HIGH MAX-HIGH
        set high_cnt high_cnt - 1 ]
      [ ifelse (low_cnt > 0) [
        set socialSkills getRandomFloat MIN-LOW MAX-LOW
        set low_cnt low_cnt - 1 ]
      [ show (word "System.err: User social skills is not initialised. Numbers do not add up: high_cnt = " high_cnt " medium_cnt = " medium_cnt " low_cnt = " low_cnt) ]
      ]]]]]]
end


;; Initialises the trust group distribution
to init-group-trust
  ifelse (init_trust_distribution = "zero") [ ask users [ set trust 0 ] ]
  [ ifelse (init_trust_distribution = "random") [ ask users [ set trust (random 11) / 10 ]]    ;; only for calibration purposes
  [ ifelse (init_trust_distribution = "all_high") [ ask users [ set trust getRandomFloat MIN-HIGH MAX-HIGH ] ]
  [ ifelse (init_trust_distribution = "all_medium") [ ask users [ set trust getRandomFloat MIN-MEDIUM MAX-MEDIUM ] ]
  [ ifelse (init_trust_distribution = "all_low") [ ask users [ set trust getRandomFloat MIN-LOW MAX-LOW ] ]
  [ ;heterogenous groups
    let low_cnt 0
    let medium_cnt 0
    let high_cnt 0

    ;; converts the interface group distribution into actual numbers
    if (init_trust_distribution = "75-25-0_lmh") [
      set low_cnt round (0.75 * numberUsers)
      set medium_cnt round (0.25 * numberUsers)
      set high_cnt 0 ]

    if (init_trust_distribution = "75-0-25_lmh") [
      set low_cnt round (0.75 * numberUsers)
      set medium_cnt 0
      set high_cnt round (0.25 * numberUsers) ]

    if (init_trust_distribution = "50-50-0_lmh") [
      set low_cnt round (0.5 * numberUsers)
      set medium_cnt round (0.5 * numberUsers)
      set high_cnt 0 ]

    if (init_trust_distribution = "50-0-50_lmh") [
      set low_cnt round (0.5 * numberUsers)
      set medium_cnt 0
      set high_cnt round (0.5 * numberUsers) ]

    if (init_trust_distribution = "50-25-25_lmh") [
      set low_cnt round (0.5 * numberUsers)
      set medium_cnt round (0.25 * numberUsers)
      set high_cnt round (0.25 * numberUsers) ]

    if (init_trust_distribution = "25-50-25_lmh") [
      set low_cnt round (0.25 * numberUsers)
      set medium_cnt round (0.5 * numberUsers)
      set high_cnt  round (0.25 * numberUsers) ]

    if (init_trust_distribution = "25-25-50_lmh") [
      set low_cnt round (0.25 * numberUsers)
      set medium_cnt round (0.25 * numberUsers)
      set high_cnt round (0.5 * numberUsers) ]

    if (init_trust_distribution = "25-75-0_lmh") [
      set low_cnt round (0.25 * numberUsers)
      set medium_cnt round (0.75 * numberUsers)
      set high_cnt 0 ]

    if (init_trust_distribution = "25-0-75_lmh") [
      set low_cnt round (0.25 * numberUsers)
      set medium_cnt 0
      set high_cnt round (0.75 * numberUsers) ]

    if (init_trust_distribution = "0-75-25_lmh") [
      set low_cnt 0
      set medium_cnt round (0.75 * numberUsers)
      set high_cnt round (0.25 * numberUsers) ]

    if (init_trust_distribution = "0-50-50_lmh") [
      set low_cnt 0
      set medium_cnt round (0.5 * numberUsers)
      set high_cnt round (0.5 * numberUsers) ]

    if (init_trust_distribution = "0-25-75_lmh") [
      ;print "init-group-composition, trust distribution: 75% high trust, 25% medium trust"
      set low_cnt 0
      set medium_cnt round (0.25 * numberUsers)
      set high_cnt round (0.75 * numberUsers) ]

    ;;Based on the number of agents with high, medium, low trust the agents are now initialised with these levels of trust
    ask users [
      ifelse (high_cnt > 0) [
        set trust getRandomFloat MIN-HIGH MAX-HIGH
        set high_cnt high_cnt - 1 ]
      [ ifelse (medium_cnt > 0) [
        set trust getRandomFloat MIN-MEDIUM MAX-MEDIUM
        set medium_cnt medium_cnt - 1 ]
      [ ifelse (low_cnt > 0) [
        set trust getRandomFloat MIN-LOW MAX-LOW
        set low_cnt low_cnt - 1 ]
      [ show (word "System.err: User trust is not initialised. Numbers do not add up: high_cnt = " high_cnt " medium_cnt = " medium_cnt " low_cnt = " low_cnt) ]
      ]]]]]]]]
end

;; Initialises the trust group distribution set in the interface
to init-group-confidence

  ifelse (init_confidenceKnowledge_distr = "random") [ ask users [ set confidenceKnowledge (random 11) / 10 ]]
  [ ifelse (init_confidenceKnowledge_distr = "zero") [ ask users [ set confidenceKnowledge 0 ]]
  [ ifelse (init_confidenceKnowledge_distr = "all_low") [ ask users [ set confidenceKnowledge getRandomFloat MIN-LOW MAX-LOW ]]
  [ ifelse (init_confidenceKnowledge_distr = "all_medium") [ ask users [ set confidenceKnowledge getRandomFloat MIN-MEDIUM MAX-MEDIUM ]]
  [ ifelse (init_confidenceKnowledge_distr = "all_high") [ ask users [ set confidenceKnowledge getRandomFloat MIN-HIGH MAX-HIGH ]]
  [  ;; Heterogeneous groups
    ;print (word "init-group-confidence: heterogeneous group:" init_confidenceKnowledge_distr)
    let low_cnt 0
    let medium_cnt 0
    let high_cnt 0

    if (init_confidenceKnowledge_distr = "minorityLow") [   ;users are already initialised with high confidence
    ;print "init-group-composition, confidence distribution: 25% low confidence, 75% high confidence"
      set low_cnt round (0.25 * numberUsers)
      set medium_cnt 0
      set high_cnt round (0.75 * numberUsers) ]

    if (init_confidenceKnowledge_distr = "minorityHigh") [   ;users are already initialised with low confidence
    ;print "init-group-composition, confidence distribution: 25% high confidence, 75% low confidence"
      set low_cnt round (0.75 * numberUsers)
      set medium_cnt 0
      set high_cnt round (0.25 * numberUsers) ]

      if (init_confidenceKnowledge_distr = "75-25-0_lmh") [
      set low_cnt round (0.75 * numberUsers)
      set medium_cnt round (0.25 * numberUsers)
      set high_cnt 0 ]

    if (init_confidenceKnowledge_distr = "75-0-25_lmh") [
      set low_cnt round (0.75 * numberUsers)
      set medium_cnt 0
      set high_cnt round (0.25 * numberUsers) ]

    if (init_confidenceKnowledge_distr = "50-50-0_lmh") [
      set low_cnt round (0.5 * numberUsers)
      set medium_cnt round (0.5 * numberUsers)
      set high_cnt 0 ]

    if (init_confidenceKnowledge_distr = "50-0-50_lmh") [
      set low_cnt round (0.5 * numberUsers)
      set medium_cnt 0
      set high_cnt round (0.5 * numberUsers) ]

    if (init_confidenceKnowledge_distr = "50-25-25_lmh") [
      set low_cnt round (0.5 * numberUsers)
      set medium_cnt round (0.25 * numberUsers)
      set high_cnt round (0.25 * numberUsers) ]

    if (init_confidenceKnowledge_distr = "25-50-25_lmh") [
      set low_cnt round (0.25 * numberUsers)
      set medium_cnt round (0.5 * numberUsers)
      set high_cnt  round (0.25 * numberUsers) ]

    if (init_confidenceKnowledge_distr = "25-25-50_lmh") [
      set low_cnt round (0.25 * numberUsers)
      set medium_cnt round (0.25 * numberUsers)
      set high_cnt round (0.5 * numberUsers) ]

    if (init_confidenceKnowledge_distr = "25-75-0_lmh") [
      set low_cnt round (0.25 * numberUsers)
      set medium_cnt round (0.75 * numberUsers)
      set high_cnt 0 ]

    if (init_confidenceKnowledge_distr = "25-0-75_lmh") [
      set low_cnt round (0.25 * numberUsers)
      set medium_cnt 0
      set high_cnt round (0.75 * numberUsers) ]

    if (init_confidenceKnowledge_distr = "0-75-25_lmh") [
      set low_cnt 0
      set medium_cnt round (0.75 * numberUsers)
      set high_cnt round (0.25 * numberUsers) ]

    if (init_confidenceKnowledge_distr = "0-50-50_lmh") [
      set low_cnt 0
      set medium_cnt round (0.5 * numberUsers)
      set high_cnt round (0.5 * numberUsers) ]

    if (init_confidenceKnowledge_distr = "0-25-75_lmh") [
      ;print "init-group-composition, trust distribution: 75% high trust, 25% medium trust"
      set low_cnt 0
      set medium_cnt round (0.25 * numberUsers)
      set high_cnt round (0.75 * numberUsers) ]

    ask users [
      ifelse (high_cnt > 0) [
        set confidenceKnowledge getRandomFloat MIN-HIGH MAX-HIGH
        set high_cnt high_cnt - 1 ]
      [ ifelse (medium_cnt > 0) [
        set confidenceKnowledge getRandomFloat MIN-MEDIUM MAX-MEDIUM
        set medium_cnt medium_cnt - 1 ]
      [ ifelse (low_cnt > 0) [
        set confidenceKnowledge getRandomFloat MIN-LOW MAX-LOW
        set low_cnt low_cnt - 1 ]
      [ show (word "System.err: User confidence is not initialised. Numbers do not add up: high_cnt = " high_cnt " medium_cnt = " medium_cnt " low_cnt = " low_cnt) ]]]]
    ]]]]]

  ;;test to check initialisation
  ;ask users  [ show confidenceKnowledge ]
end
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; GO
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;


;; Main function of AgentEx. The agents communicate (or not), form group knowledge,
;; Calculate their individual and group extraction level (if there is communication), choose extraction level, extract.
;; The resource is then updated/regrowing and disclosed to the agents.
;; They can update their confidenceKnowledge, trust and knowledge before they start communicating again.
to go
  ;show (word "Tick: " ticks)                ;; print the tick number for easier readability of output

  if( ticks > endOfGame)
  [ response-vars-end
    stop  ]                                  ;; this check whether the simulation run needs to end.
  ifelse (resourceStockSize > 0)[            ;; the users are still playing
    prepare-step                             ;; (re)set relevant variables in the beginning of a new tick
    ask users [ communicate-and-form-group-knowledge ]
    determine_domConfSpeaker
    ask users [
      update-individual-knowledge
      calculate-individual-extraction-level ]
    calculate-group-extraction-level
    ask users [ choose-extraction-level ]
    ;;show (word "numPlannedExtraction: " numPlannedExtraction "; numGroupPlannedExtraction: " numGroupPlannedExtraction "; Total Extraction: " totalExtraction)
    ask users [ extract ]
    regrow-resource-stock
    ask users [ update-confidence-trust ]
    set numSpeakers sum [speaker] of users
    layout
  ] ;; resource < 0 => is depleted
  [ if not depleted  [
      set depleted true
      set time-of-depletion ticks
      set-zero-after-depletion ]]  ;;first tick after depletion
  calc-response-vars
  tick
end


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; FUNCTIONS -  Main processes of AgentEx (A-H)
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

;; A. If the agent is a speaker, the agent will share its individualKnowledge with the others
;; Function describes how group knowledge is formed based on the speakers, there are 4 options:
;; a) average knowledge of speakers b) weighted average of knowledge of speakers based on confidenceKnowledge
;; c) kowledge of dominant speaker based on max social skill or d) max confidence
to communicate-and-form-group-knowledge
  if (speaker = 1) [
    if (groupKnowledgeFormation = "average") [
    set groupKnowledge groupKnowledge + individualKnowledge / numberUsersCom
  ]
  if (groupKnowledgeFormation = "weightedAverage")[
    ifelse (confidenceSum > 0) [
      set groupKnowledge groupKnowledge + (individualKnowledge * confidenceKnowledge / confidenceSum)
    ][
    set groupKnowledge groupKnowledge + individualKnowledge / numberUsersCom
  ]]
  if (groupKnowledgeFormation = "dominanceSocialSkills")[
    if self = dominantSocialSpeaker [
      set dominantSocialSkill socialSkills
      set groupKnowledge individualKnowledge
  ]]
  if (groupKnowledgeFormation = "dominanceConfidence")[
    if (confidenceKnowledge = dominantConfidence and confSpeakerBefore = self) [
      set domConfSpeaker self
      set dominantConfidence confidenceKnowledge
      set groupKnowledge individualKnowledge
    ]
    if (confidenceKnowledge > dominantConfidence) [
      set domConfSpeaker self
      set dominantConfidence confidenceKnowledge
      set groupKnowledge individualKnowledge
    ]
  ]]
end

;; B. Function describes whether and how the agent's knowledge is updated.
;; Direction/Type of change: towards group knowledge, random, no change
;; IF there is NO communication, confidence related probablity that it updates its knowledge randomly - high confidence - low prob to change and vice versa
;; IF there is communication: most agents will update their knowledge towards the group knowledge, however, their is always a small probablity that the direction
;; of change is random or no change (confidence related probability update).
to update-individual-knowledge
  ifelse (numberUsersCom != 0) [
    ifelse (((random 11) / 10) < probIND) [
      ;print "update group"
      set individualKnowledge (1 - confidenceKnowledge) ^ 2 * (groupKnowledge - individualKnowledge) + individualKnowledge ]
    [ if (((random 11) / 10) <= (1 - confidenceKnowledge)) [     ;; in case random value > probInd -> the agent updates its knowledge randomly by a probability depending on its confidence
      ;print "randomly update"
      ifelse (exp-type = "informed") [
        set individualKnowledge 25 + random (29 + 1 - 25)
      ][ ifelse (exp-type = "uninformed") [
        set individualKnowledge 5 + random (24 + 1 - 5) ] ; 30 + random (49 + 1 - 30)

      [ set individualKnowledge getRandomKnowledge ]]           ; default (non-experiment scenario mode)
    ]]]
  [ if (((random 11) / 10) <= (1 - confidenceKnowledge)) [      ;; no communication case (doesn't apply to the scenario experiments)
    set individualKnowledge getRandomKnowledge ]
  ]
    ;show (word "individualKnowledge: " individualKnowledge " trust: " trust " confidence: " confidenceKnowledge " speaker: " speaker)
end


;; C. Agent determines how much it would extract for itself, i.e., formulates its individual extraction level
;; The extraction level is affected by:
;; - individual knowledge: what is the right X amount of resource to take out given the current resourceStocksize
;; - social preferences: equal sharing based on individualKnowledge (divide X by number of users)
to calculate-individual-extraction-level
  ifelse (resourceStockSize < individualKnowledge)
    [ set plannedExtraction 0]
    [ ifelse (socialPreferences = 1)
      [ set plannedExtraction (resourceStockSize - individualKnowledge) / numberUsers ]
      [ set plannedExtraction (resourceStocksize - individualKnowledge) / numberUsers + random  (resourceStocksize - individualKnowledge)]] ;; socialPreferences = 0
     ;; show (word " individual extraction level: " plannedExtraction)
end

;; D. If there is no communication/group agreement, groupPlannedExtraction is 0
;; If there is communication/group agreement, groupPlanendExtraction = groupKnowledge / numberUsers
to calculate-group-extraction-level
  if (numberUsersCom != 0)[
    ifelse (resourceStockSize < groupKnowledge)
    [ set groupPlannedExtraction 0]
    [ set groupPlannedExtraction (resourceStockSize - groupKnowledge) / numberUsers]
    ;; groupPlannedExtraction is individual extraction if user decides to go for group extraction level
  ]
end

;; E. The user decides whether to go for the group extraction level (groupPlannedExtraction) or for its individual extraction level (plannedExtraction) based on the difference
;; between the extraction levels and its trust in the group and social preferences
;; - The group extraction level is chosen when this allows to provide more or the same as the individual extraction level (no matter trust and social prefernces)
;; - The group extraction level is chosen (even when providing less than the individual extraction level) when the agent has social preferences and trust is high enough (i.e. trust-based propbability to go for the group)
to choose-extraction-level

  ifelse (numberUsersCom < 1 )[                                                ;; no communication
    set actualExtraction plannedExtraction
    set numPlannedExtraction numPlannedExtraction + 1
    set cooperation false ]
  ;; there is communication
  [  ifelse (groupPlannedExtraction >= plannedExtraction)                      ;; group extraction level provides more than or the same as the individual extraction level
    [ set actualExtraction groupPlannedExtraction                              ;; -> group extraction level
      set numGroupPlannedExtraction numGroupPlannedExtraction + 1 ]
    [ if (groupPlannedExtraction < plannedExtraction)[                         ;; group extraction level provides less than the individual extraction level
        ifelse (socialPreferences = 0) [                                       ;; agents with no social preferences -> go for individual extraction level
          set actualExtraction plannedExtraction
          set numPlannedExtraction numPlannedExtraction + 1
          set cooperation false ]
        [ ifelse (((random 11) / 10) <= (trust)) [                             ;; agent with social preferences -> there is a probability (trust based) to go for the group extraction level
          set actualExtraction groupPlannedExtraction
          set numGroupPlannedExtraction numGroupPlannedExtraction + 1 ]
          [ set actualExtraction plannedExtraction
            set numPlannedExtraction numPlannedExtraction + 1
            set cooperation false ]]]]
  ]

  ;;print groupPlannedExtraction
  ;;show (word "extraction: " actualExtraction " GroupPlannedExtraction: " groupPlannedExtraction)
  set totalExtraction totalExtraction + actualExtraction
  ;show actualExtraction
end

;; F. The actual extraction takes place
to extract
  if (totalExtraction > resourceStockSize) [                                    ;; the proportional amount of actualExtraction if resourceStockSize is smaller than sum of actualExtractions
    set actualExtraction (actualExtraction / totalExtraction) * resourceStockSize
    set totalExtraction resourceStockSize
    ]
  set accumulatedExtraction accumulatedExtraction + actualExtraction
end

;; G. Stock is updated after extraction
;; replenishing amount is based on the current stocksize (see look-up table above)
to regrow-resource-stock
 set stockSizeBeforeGrowth resourceStockSize - totalExtraction
 ;;print stockSizeBeforeGrowth
 set resourceRegrowth table:get regrowthTable round(stockSizeBeforeGrowth)
 ;;show (word "stockSizeBeforeGrowth: " stockSizeBeforeGrowth "; resourceRegrowth: " resourceRegrowth )
 set resourceStockSize resourceStocksize - totalExtraction + resourceRegrowth
 if (resourceStockSize < 0) [
   set resourceStockSize 0                                                    ;; players will stop playing
 ]
 ;;show (word "resourceStockSize: " resourceStockSize)
 ;;print resourceRegrowth
 ;;print totalExtraction
end

;; H. If there is a deviation from what is expected from the resource system
;; both trust in others and confidence in ones knowledge is affected (when there is no group agreement there is no expectation, thus, no deviation):
;; - Positive deviation == underexploitation ==> confidence decreases (the system is not understood properly -> knowledge)
;; - Negative deviation == overexploitation  ==> both confidence and trust decreases (someone made a mistake/cheated -> trust; AND the system is not understood properly -> knowledge)
;; - No deviation == as expected ==> both confidence and trust increases (everyone behaved as agreed -> trust; AND the system seems to be understood properly -> knowledge)
to update-confidence-trust
  let confidenceKnowledgeThreshold 1 ; future work - value of 1 means that the confidence level does not influence the change
  let learningRate 1  ; future work

  ifelse (numberUsersCom != 0) [   ;; there is communication
    let sBeforeGrowth resourceStockBeforeExtraction - ((numberUsers - 1) * groupPlannedExtraction + actualExtraction) ;; the agent assumes that in the case of communication all other agents follow the group extraction level
    if (sBeforeGrowth < 0) [set sBeforeGrowth 0]
    let expectedResourceStockSize sBeforeGrowth + (table:get regrowthTable round(sBeforeGrowth))
    set deviation (resourceStockSize - expectedResourceStockSize)
    ;show (word "deviation: " deviation " update = " (confTrust_update_constant * deviation * deviationSensitivity))

    if (deviation < 0) [
      set trust trust - learningRate * confTrust_update_constant * abs (deviation) * deviationSensitivity        ;; overexploitation
      ;;set trust trust + ((trust * trust) / (1 + (trust * trust))) * deviation                                  ;; sigmoid trust function (depending on previous trust level and proportional to deviation)
      if (confidenceKnowledge < confidenceKnowledgeThreshold)[
      set confidenceKnowledge confidenceKnowledge - learningRate * confTrust_update_constant * abs (deviation) * deviationSensitivity]
    ]
    if (deviation > 0) [                                                                                         ;; underexploitation
      if (confidenceKnowledge < confidenceKnowledgeThreshold)[
      set confidenceKnowledge confidenceKnowledge - learningRate * confTrust_update_constant * deviation * deviationSensitivity]
    ]
    if (deviation = 0) [
      set confidenceKnowledge confidenceKnowledge + learningRate * confTrust_update_constant
      set trust trust + learningRate * confTrust_update_constant
      ;;set trust trust - ((trust * trust) / (1 + (trust * trust)))                            ;; sigmoid trust function (depending on previous trust level)
  ]]

  [ ;; else condition: if there is no communication, i.e. groupPlannedExtraction = 0
    let sBeforeGrowth  resourceStockBeforeExtraction - numberUsers * plannedExtraction         ;; this assumes that all users are doing the same (mirroring)
    if (sBeforeGrowth < 0) [set sBeforeGrowth 0]
    let expectedResourceStockSize sBeforeGrowth + (table:get regrowthTable round(sBeforeGrowth))
    set deviation round(resourceStockSize - expectedResourceStockSize)
   ifelse (deviation = 0) [
      set confidenceKnowledge confidenceKnowledge + confTrust_update_constant]
      [set confidenceKnowledge confidenceKnowledge - confTrust_update_constant * abs (deviation)]
  ]

  if (confidenceKnowledge > 1) [set confidenceKnowledge 1]
  if (confidenceKnowledge < 0) [set confidenceKnowledge 0.0001]                                ;; to ensure that confidenceKnowledge never </= 0
  if (trust > 1) [set trust 1]
  if (trust < 0) [set trust 0]
end


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; FUNCTIONS - Individual User (Agent)
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

;; determine who is speaker and which one is the dominant speaker (based on socialSkills or confidenceKnowledge)
;; Agents with high social skills are more probable to be a speaker
;; once a speaker always a speaker (might change in future)
to determine-speakers
 ifelse (NOT Experiment) [
   ask users [
     if (socialSkills_distribution != "noone") [
      if  (((random 11) / 10) <= socialSkills) [                            ;; the higher the social skills the higher the probability it becomes a speaker
        set speaker 1
        set numberUsersCom numberUsersCom + 1
      ]]
   ]
   let speakers users with [speaker = 1]
   if any? speakers [
     ask max-one-of (users with [speaker = 1]) [socialSkills] [              ;; (one of the) speaker(s) with highest social skills is selected as dominant speaker
      set dominantSocialSpeaker self
     ]
     ask max-one-of (users with [speaker = 1]) [confidenceKnowledge] [       ;; (one of the) speaker(s) with highest confidence in knowledge is selected as dominant speaker
      set domConfSpeaker self
     ]
    ]
   ]
 [set numberUsersCom numberUsersCom + 1]
end

;; calculate the sum of all confidence values to use in the weighting of the knowledge contributions
to calculate-confidence-weight
  if (speaker = 1) [
  set confidenceSum confidenceSum + confidenceKnowledge
  ]
end

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; Functions - Group
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

;; Determines which speaker spoke this round IF dominantConfidence based groupKnowledgeFormation is selected
;; to ensure that this dominant speaker remains dominant even though another speaker might have reached the same confidence level (to prevent fluctuations in groupKnowledge)
to determine_domConfSpeaker
  set confSpeakerBefore domConfSpeaker
end


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; Functions - Resource
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

;; Resource dynamics represented as look-up table follows a discrete version of a logistic growth function
;; Source: Figure 2 in Lindahl et al 2016
to create-regrowth-table
  set regrowthTable table:make
  table:put regrowthTable 50 0
  table:put regrowthTable 49 1
  table:put regrowthTable 48 1
  table:put regrowthTable 47 1
  table:put regrowthTable 46 1
  table:put regrowthTable 45 1
  table:put regrowthTable 44 3
  table:put regrowthTable 43 3
  table:put regrowthTable 42 3
  table:put regrowthTable 41 3
  table:put regrowthTable 40 3
  table:put regrowthTable 39 5
  table:put regrowthTable 38 5
  table:put regrowthTable 37 5
  table:put regrowthTable 36 5
  table:put regrowthTable 35 5
  table:put regrowthTable 34 7
  table:put regrowthTable 33 7
  table:put regrowthTable 32 7
  table:put regrowthTable 31 7
  table:put regrowthTable 30 7
  table:put regrowthTable 29 9
  table:put regrowthTable 28 9
  table:put regrowthTable 27 9
  table:put regrowthTable 26 9
  table:put regrowthTable 25 9
  table:put regrowthTable 24 7
  table:put regrowthTable 23 7
  table:put regrowthTable 22 7
  table:put regrowthTable 21 7
  table:put regrowthTable 20 7
  table:put regrowthTable 19 5
  table:put regrowthTable 18 5
  table:put regrowthTable 17 5
  table:put regrowthTable 16 5
  table:put regrowthTable 15 5
  table:put regrowthTable 14 3
  table:put regrowthTable 13 3
  table:put regrowthTable 12 3
  table:put regrowthTable 11 3
  table:put regrowthTable 10 3
  table:put regrowthTable 9 1
  table:put regrowthTable 8 1
  table:put regrowthTable 7 1
  table:put regrowthTable 6 1
  table:put regrowthTable 5 1
  table:put regrowthTable 4 0
  table:put regrowthTable 3 0
  table:put regrowthTable 2 0
  table:put regrowthTable 1 0
  table:put regrowthTable 0 0
end

;; Table with the optimal claims for each resource stock size
;; Source: Appendix A5.1 in Schill et al. 2015
to create-optimalClaim-table
  set optimalExtractionTable table:make
  table:put optimalExtractionTable 50 25
  table:put optimalExtractionTable 49 24
  table:put optimalExtractionTable 48 23
  table:put optimalExtractionTable 47 22
  table:put optimalExtractionTable 46 21
  table:put optimalExtractionTable 45 20
  table:put optimalExtractionTable 44 19
  table:put optimalExtractionTable 43 18
  table:put optimalExtractionTable 42 17
  table:put optimalExtractionTable 41 16
  table:put optimalExtractionTable 40 15
  table:put optimalExtractionTable 39 14
  table:put optimalExtractionTable 38 13
  table:put optimalExtractionTable 37 12
  table:put optimalExtractionTable 36 11
  table:put optimalExtractionTable 35 10
  table:put optimalExtractionTable 34 9
  table:put optimalExtractionTable 33 8
  table:put optimalExtractionTable 32 7
  table:put optimalExtractionTable 31 6
  table:put optimalExtractionTable 30 5
  table:put optimalExtractionTable 29 4
  table:put optimalExtractionTable 28 3
  table:put optimalExtractionTable 27 2
  table:put optimalExtractionTable 26 1
  table:put optimalExtractionTable 25 0
  table:put optimalExtractionTable 24 4
  table:put optimalExtractionTable 23 3
  table:put optimalExtractionTable 22 2
  table:put optimalExtractionTable 21 1
  table:put optimalExtractionTable 20 0
  table:put optimalExtractionTable 19 4
  table:put optimalExtractionTable 18 3
  table:put optimalExtractionTable 17 2
  table:put optimalExtractionTable 16 1
  table:put optimalExtractionTable 15 0
  table:put optimalExtractionTable 14 4
  table:put optimalExtractionTable 13 3
  table:put optimalExtractionTable 12 2
  table:put optimalExtractionTable 11 1
  table:put optimalExtractionTable 10 0
  table:put optimalExtractionTable 9 0
  table:put optimalExtractionTable 8 0
  table:put optimalExtractionTable 7 0
  table:put optimalExtractionTable 6 0
  table:put optimalExtractionTable 5 0
  ;; not in the appendix. Since regeneration rate = 0 if stock size < 5 -> it is optimal to take what is left
  table:put optimalExtractionTable 4 4
  table:put optimalExtractionTable 3 3
  table:put optimalExtractionTable 2 2
  table:put optimalExtractionTable 1 1
  table:put optimalExtractionTable 0 0
end


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; Functions - Layout
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

;; Updates the visualization whether the users
;; - speak (presence of a speaking bubble)
;; - color the user (turn green vs. orange) based on a) social preferences or b) behaviour (ind. vs. group extraction level)
;; c) dominance (the speaker who influences the knowledge formation process)
to layout
  ask users with [speaker = 1]
  [ set shape "speaker" ]

  if (meaningOfUserColour = "colourSocialPreferences")[
    ask users with [socialPreferences = 1] [
      set color green
    ]]
  if (meaningOfUserColour = "colourBehavior")[
    ask users [
      ifelse (actualExtraction = groupPlannedExtraction) [
      set color green]
      [set color red]
    ]]
  if (meaningOfUserColour = "colourDominance")[
      if (groupKnowledgeFormation = "dominanceSocialSkills") [
      ask users [
        ifelse ( dominantSocialSpeaker = self)
        [ set color green ]
        [set color red]
    ]]
    if (groupKnowledgeFormation = "dominanceConfidence") [
      ask users [
        ifelse ( domConfSpeaker = self)
        [ set color green ]
        [set color red]
      ]]
     ]
  color-pond
end

;; Visualization of the resource stock size (changes of the intesity of blue, white = depleted stock)
to color-pond
  ask patch 0 0 [
    let resourceColor scale-color blue resourceStockSize 50 0
    ask patches in-radius 4
    [set pcolor resourceColor]
  ]
end

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; Functions - Misc
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

;; Initialization of the simulation
to prepare-step
   set resourceStockBeforeExtraction resourceStockSize
   set groupKnowledge 0
   set confidenceSum 0
   set resourceRegrowth 0
   set totalExtraction 0
   ask users [
     calculate-confidence-weight
     check-range-variables]
   set groupPlannedExtraction 0
   set numPlannedExtraction 0
   set dominantConfidence 0
   set dominantSocialSkill 0
   set confSpeakerBefore domConfSpeaker

   ifelse (cooperation and ticks > 0)
   [ set cooperationHistory cooperationHistory + 1
     set cooperationCount cooperationCount + 1 ]
   [ set cooperationHistory 0 ]

   set cooperation true
   set numGroupPlannedExtraction 0

   set meanTrust 0
   set meanConfidence 0
   set meanIndKnow 0
   set sdTrust 0
   set sdConfidence 0
   set sdIndKnow 0
   set medianTrust 0
   set medianConfidence 0
   set medianIndKnow 0
end
;;Sets those variables that need to become and stay zero afer depletion
to set-zero-after-depletion
  ask users [
    set speaker 0
    set plannedExtraction 0
    set actualExtraction 0
    set deviation 0
    ]
  set totalExtraction 0
  set meanTrust 0
  set meanConfidence 0
  set meanIndKnow 0
  set sdTrust 0
  set sdConfidence 0
  set sdIndKnow 0
  set medianTrust 0
  set medianConfidence 0
  set medianIndKnow 0
end

;; Maintain variable value range(s)
to check-range-variables
  if individualKnowledge > 50 [
   set individualKnowledge 50
  ]
end

;; Function returns a random number between the range <IND-KNOW-MIN,IND-KNOW-MAX>
to-report getRandomKnowledge
  let val IND-KNOW-MIN + random (IND-KNOW-MAX + 1 - IND-KNOW-MIN)  ; random value between IND-KNOW-MIN <= x < IND-KNOW-MAX + 1, the function random does not take the max value into account, therefore the +1
  report val

  ;;print "getRandomKnowledge(): Sys.Err there is no valid distribution in use"
end

to-report getRandomFloat [ minVal maxVal ]
  let val minVal + random-float (maxVal + 0.001 - minVal)  ;; random value between minVal <= x < maxVal + 0.001, the function random does not take the max value into account, therefore the + 0.001
  report val

 end
;; adopted from https://subversion.american.edu/aisaac/notes/netlogo-intro.xhtml#plotting-gini-coefficient-and-lorenz-curve
;;Written by Seth Tisue
to-report partial-sums [nums]
  let total 0
  let result []
  foreach nums [
    set total total + ?
    set result lput total result
  ]
  report result
end
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; Functions - Logging vars (summary statistics)
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to calc-response-vars
  track-sustainability
  calc-efficiency
  calc-GINI
  calc-GINI-approx
  summary-stats
  ask user 0 [ set individualKnowledge1 individualKnowledge ]
  ask user 1 [ set individualKnowledge2 individualKnowledge ]
  ask user 2 [ set individualKnowledge3 individualKnowledge ]
  ask user 3 [ set individualKnowledge4 individualKnowledge ]
end

;; Calculates the mean and standard deviation of trust, confidenceKnowledge and individualKnowledge
;; representing the distribution of these user-own values for each tick
to summary-stats
  let trustList [ trust ] of users
  let confidenceList [ confidenceKnowledge ] of users
  let indKnowList [ individualKnowledge ] of users

  set meanTrust mean trustList
  set sdTrust standard-deviation trustList
  set medianTrust median trustList
  set meanConfidence mean confidenceList
  set sdConfidence standard-deviation confidenceList
  set medianConfidence median confidenceList
  set meanIndKnow mean indKnowList
  set sdIndKnow standard-deviation indKnowList
  set medianIndKnow median indKnowList

  set stockSizeList lput stocksizeBeforeGrowth stockSizeList
  set efficiencyList lput efficiency efficiencyList
  set groupKnowledgeList lput groupKnowledge groupKnowledgeList
  set totalExtractionList lput totalExtraction totalExtractionList

  ;print (word "stockSizeList: " stockSizeList)
  ;print (word "efficiencyList: " efficiencyList)
  ;print (word "groupKnowledgeList: " groupKnowledgeList)
  ;print (word "totalExtractionList: " totalExtractionList)

  ;print ticks
  ;print (word "trust mean: " (precision meanTrust 2) ", sd: " (precision sdTrust 2) " trustList: " trustList)
  ;print (word "confidence mean: " precision meanConfidence 2 ", sd: " precision sdConfidence 2 " confidenceList: " confidenceList)
  ;print (word "individualKnowledge mean: " precision meanIndKnow 2 ", sd: " precision sdIndKnow 2 " indKnowList: " indKnowList)
end

;; tracks whether, from tick 5 onwards, the group was behaving optimal, over- or under- exploiting
to track-sustainability
  ;print stockSizeBeforeGrowth
  ifelse (stockSizeBeforeGrowth < 25) [
    set overExpl true
    set underExpl false
    set optimal false ]
  [ ifelse (stockSizeBeforeGrowth > 29) [
      set underExpl true
      set overExpl false
      set optimal false ]
    [ set optimal true   ; stocksize in optimal zone [25,29]
      set underExpl false
      set overExpl false ]]
  ifelse ticks > 4 [                                    ;; we are only interested in what happens after the first 4 ticks
    ifelse (stockSizeBeforeGrowth < 25) [ set overExploit_cnt overExploit_cnt + 1 ]
  [ ifelse (stockSizeBeforeGrowth > 29) [ set underExploit_cnt underExploit_cnt + 1 ]
    [ set optimal_cnt optimal_cnt + 1 ]]]                ; stocksize in optimal zone [25,29]
  [ if depleted [ set overExploit_cnt overExploit_cnt + 1 ]] ;; the case there has been depletion in the first few ticks
end

;; Function calculates GINI, a measure of inequality of a distribution (Gini,1912), here extraction
;; 0 = equality; 1 = maximal inequality
;; Ratio of the areas on the Lorenz curve diagram (proportion of total S (e.g. income) corresponding the cumulative S of the x% of the population.
;; adapted the implementation at https://subversion.american.edu/aisaac/notes/netlogo-intro.xhtml#plotting-gini-coefficient-and-lorenz-curve
;; calculate it in the very end
;; Changed: actualExtraction should be accumulatedExtraction
to calc-GINI
  let cumsum-sorted-extraction partial-sums sort [ accumulatedExtraction ] of users
  ;print (word "cumsum-sorted-extraction: " cumsum-sorted-extraction)
  let total-extraction last cumsum-sorted-extraction
  set normalized-extraction n-values numberUsers [ 0 ]
  ifelse (total-extraction > 0 ) [
    set normalized-extraction map [? / total-extraction] cumsum-sorted-extraction
    ;print (word "normalized-extraction: " normalized-extraction)
    let gaps n-values numberUsers [((? + 1) / numberUsers) - item ? normalized-extraction]
    set gini (2 * sum gaps / numberUsers)                                  ;; Gini = A/(A+B) = 2*A
    ;print (word "gaps: " gaps " gini: " precision gini 2)
  ][ set gini 0]   ;; the rare case that there was no extraction before and in the following round there will also be no extraction
  ;print gini
end

;; The function that approximates the GINI coefficient
;; SUM(2*i - n - 1)*xi  / n^2*meanExtraction  | n = 4, i = order index of sorted extraction (highest index = 4, lowest = 1)
to calc-GINI-approx
  let actualExtrList sort [ accumulatedExtraction ] of users
  let xtimesExtr n-values numberUsers [ (2 * (? + 1) - numberUsers - 1) * (item ? actualExtrList) ]
  ;print (word "actualExtrList = " actualExtrList " xtimesExtr = " xtimesExtr)
  let sumXtimesExtr sum xtimesExtr                                        ;; nominator
  let meanExtr mean actualExtrList
  ;print (word  "sumXtimesExtr = " sumXtimesExtr " meanExtr = " meanExtr)
  ifelse (meanExtr != 0) [
    set gini-approx sumXtimesExtr / ((numberUsers ^ 2) * meanExtr) ]
  [ set gini-approx 0 ]                                                   ;; Gini is 0 when all take 0
  ;print (word "gini-approx = " gini-approx " nominator = " sumXtimesExtr " denominator = 16 * " meanExtr " = " (16 * meanExtr))
end

;: Function to calculate the efficiency [0,1], 1 is optimal
;; value based on taking more than what is optimal = deviation (dev))
;; dev >= 1, if dev = 1 = optimal, if dev > 1 = overexploiting dev < 0 = underexploit (not reflected in efficiency)
to calc-efficiency
  ifelse (depleted = true) [
    set efficiency 0 ]
  [ let optimalExtraction (table:get optimalExtractionTable round(resourceStockBeforeExtraction))
    ifelse (optimalExtraction < 1)[
      ifelse (totalExtraction < 1) [ set efficiency 1 ] [ set efficiency 0 ]
    ; print (word "efficiency = " efficiency " extraction = " totalExtraction " optimalExtraction = " optimalExtraction " (stocksizebeforeExtr = " resourceStockBeforeExtraction ")")
    ]
    [ let dev totalExtraction / optimalExtraction                       ;;
      ifelse (dev < 1)
      [ set efficiency dev ]          ;; optimal = taking the optimalExtraction or less
      [ set efficiency 1 / dev ]      ;; overexploit
  ;print (word "efficiency = " efficiency " dev = "  dev " extraction = " totalExtraction " optimalExtraction = " optimalExtraction " (stocksizebeforeExtr = " resourceStockBeforeExtraction ")")
    ]]
end

;; Response variables that need to be calculated at the end of the game (= after 14 ticks)
;;Stocksize, efficiency and group knowledge: mean, sd and meadian
;; coopPower: % time steps with 100% group extraction level - end of game
to response-vars-end
  set meanStocksizeBG mean stockSizeList
  set sdStocksizeBG standard-deviation stockSizeList
  set medianStocksizeBG median stockSizeList

  set coopPower cooperationCount / ticks    ; accounts for depletion and regarding the 'game as ended' to calc the proportion - coop Power.

  set meanEfficiency mean efficiencyList
  set sdEfficiency standard-deviation efficiencyList
  set medianEfficiency median efficiencyList

  set meanGroupKnowledge mean groupKnowledgeList
  set sdGroupKnowledge standard-deviation groupKnowledgeList
  set medianGroupKnowledge median groupKnowledgeList

  set sumTotalExtraction sum totalExtractionList
  set meanTotalExtraction mean totalExtractionList
  set sdTotalExtraction standard-deviation totalExtractionList
  set medianTotalExtraction median totalExtractionList

  ;to test
  ;print (word "StocksizeBG" stockSizeList)
  ;print (word "StocksizeBG - mean: " precision meanStocksizeBG 2 " sd: "  precision sdStocksizeBG 2 " median: " precision medianStocksizeBG 2)
  ;print (word "efficiencyList" efficiencyList)
  ;print (word "Efficiency - mean: " precision meanEfficiency 2 " sd: "  precision sdEfficiency 2 " median: " precision medianEfficiency 2 )
  ;print (word "groupKnowledgeList" groupKnowledgeList)
  ;print (word "GroupKnowledge - mean: " meanGroupKnowledge " sd: "  sdGroupKnowledge " median: " medianGroupKnowledge)
  ;print (word "Extraction" totalExtractionList)
  ;print (word "Extraction - sum: " sumTotalExtraction " mean: " precision meanTotalExtraction 2 " sd: "  precision sdTotalExtraction 2 " median: " medianTotalExtraction 2)

  ;print (word "overexploitance? " overexploitingGroup " (overExploit_cnt = " overExploit_cnt ")")
  ;print (word "underexploitance? " underexploitingGroup " (underExploit_cnt = " underExploit_cnt ")")
  ;print (word "optimalGroup? " optimalGroup " (optimal_cnt = " optimal_cnt ")")
end
@#$#@#$#@
GRAPHICS-WINDOW
208
53
453
311
8
8
13.4
1
10
1
1
1
0
1
1
1
-8
8
-8
8
0
0
1
ticks
10.0

BUTTON
209
12
283
45
NIL
setup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
292
12
363
45
NIL
go
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
0

PLOT
718
187
955
339
Group knowledge
Round
NIL
0.0
14.0
0.0
50.0
false
false
"" ""
PENS
"groupKnowledge" 1.0 0 -16777216 true "" "plot groupKnowledge"
"25" 1.0 2 -3026479 true "" "plot 25"
"29" 1.0 2 -3026479 true "" "plot 29"

BUTTON
370
13
445
46
step
go
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

PLOT
717
31
956
181
Resource stock size (before growth)
Round
NIL
0.0
14.0
0.0
50.0
false
true
"" ""
PENS
"25 stock" 1.0 2 -7500403 false "" "plot 25"
"beforeGrowth" 1.0 0 -13840069 false "" "plot stockSizeBeforeGrowth"
"29 stock" 1.0 2 -7500403 false "" "plot 29"

PLOT
460
31
712
181
Ind. vs. group extraction level
Round
NIL
0.0
14.0
0.0
4.0
false
true
"" ""
PENS
"Ind" 1.0 0 -955883 true "" "plot numPlannedExtraction"
"Group" 1.0 0 -10899396 true "" "plot numGroupPlannedExtraction"
"#4" 1.0 2 -14737633 false "" "plot 4"
"#3" 1.0 2 -3026479 false "" "plot 3"
"#2" 1.0 2 -3026479 false "" "plot 2"
"#1" 1.0 2 -3026479 false "" "plot 1"

MONITOR
970
239
1142
284
Group planned extraction
groupPlannedExtraction
2
1
11

PLOT
460
343
711
486
Trust
Round
NIL
0.0
14.0
0.0
1.0
false
true
"" ""
PENS
"user 0" 1.0 0 -16514302 true "" "plot [trust] of user 0"
"user 1" 1.0 0 -7500403 true "" "plot [trust] of user 1"
"user 2" 1.0 0 -5298144 true "" "plot [trust] of user 2"
"user 3" 1.0 0 -15040220 true "" "plot [trust] of user 3"

PLOT
719
496
954
643
Accumulated extraction
Round
NIL
0.0
14.0
0.0
100.0
false
true
"" ""
PENS
"user 0" 1.0 0 -16777216 true "" "plot [accumulatedExtraction] of user 0"
"user 1" 1.0 0 -7500403 true "" "plot [accumulatedExtraction] of user 1"
"user 2" 1.0 0 -5298144 true "" "plot [accumulatedExtraction] of user 2"
"user 3" 1.0 0 -15040220 true "" "plot [accumulatedExtraction] of user 3"

PLOT
461
186
712
340
Individual knowledge
Round
NIL
0.0
14.0
0.0
50.0
true
true
"" ""
PENS
"user 0" 1.0 0 -16777216 true "" "plot [individualKnowledge] of user 0"
"user 1" 1.0 0 -7500403 true "" "plot [individualKnowledge] of user 1"
"user 2" 1.0 0 -2674135 true "" "plot [individualKnowledge] of user 2"
"user 3" 1.0 0 -15040220 true "" "plot [individualKnowledge] of user 3"
"stock 25" 1.0 2 -3026479 false "" "plot 25"
"stock 29" 1.0 2 -4539718 false "" "plot 29"

PLOT
720
343
955
491
Confidence in knowledge
Round
NIL
0.0
14.0
0.0
1.0
true
true
"" ""
PENS
"user 0" 1.0 0 -16777216 true "" "plot [confidenceKnowledge] of user 0"
"user 1" 1.0 0 -7500403 true "" "plot [confidenceKnowledge] of user 1"
"user 2" 1.0 0 -5298144 true "" "plot [confidenceKnowledge] of user 2"
"user 3" 1.0 0 -15040220 true "" "plot [confidenceKnowledge] of user 3"

CHOOSER
13
428
197
473
groupKnowledgeFormation
groupKnowledgeFormation
"average" "weightedAverage" "dominanceSocialSkills" "dominanceConfidence"
1

CHOOSER
210
339
443
384
meaningOfUserColour
meaningOfUserColour
"colourSocialPreferences" "colourBehavior" "colourDominance"
0

INPUTBOX
355
392
442
473
manualSeed
1
1
0
Number

SWITCH
211
392
352
425
autoRandomSeed
autoRandomSeed
0
1
-1000

MONITOR
211
428
352
473
autoSeed
autoSeed
17
1
11

PLOT
463
495
712
645
Actual extraction
Round
NIL
0.0
14.0
0.0
15.0
true
true
"" ""
PENS
"user 0" 1.0 0 -16777216 true "" "plot [actualExtraction] of user 0"
"user 1" 1.0 0 -7500403 true "" "plot [actualExtraction] of user 1"
"user 2" 1.0 0 -2674135 true "" "plot [actualExtraction] of user 2"
"user 3" 1.0 0 -15040220 true "" "plot [actualExtraction] of user 3"

CHOOSER
13
77
193
122
socialSkills_distribution
socialSkills_distribution
"noone" "random" "all_high" "all_low" "75-0-25_lmh" "50-0-50_lmh" "25-0-75_lmh"
1

TEXTBOX
16
52
171
92
Independent variables
14
105.0
1

CHOOSER
14
171
195
216
init_confidenceKnowledge_distr
init_confidenceKnowledge_distr
"zero" "random" "all_high" "all_medium" "all_low" "75-0-25_lmh" "50-0-50_lmh" "25-0-75_lmh"
1

CHOOSER
14
124
194
169
socialPreferences_distribution
socialPreferences_distribution
"noone" "all" "random" "25%" "50%" "75%"
1

TEXTBOX
18
318
168
336
Control variables
14
105.0
1

CHOOSER
14
218
196
263
init_trust_distribution
init_trust_distribution
"zero" "random" "all_high" "all_medium" "all_low" "75-0-25_lmh" "50-0-50_lmh" "25-0-75_lmh"
0

MONITOR
970
190
1142
235
Number of speakers
numSpeakers
17
1
11

TEXTBOX
460
10
610
28
Outcome variables
14
105.0
1

TEXTBOX
17
11
167
42
AgentEx
25
103.0
1

PLOT
960
346
1186
489
Deviation stock size
Round
NIL
0.0
14.0
-10.0
10.0
true
true
"" ""
PENS
"user 0" 1.0 0 -16777216 true "" "plot [deviation] of user 0"
"user 1" 1.0 0 -7500403 true "" "plot [deviation] of user 1"
"user 2" 1.0 0 -2674135 true "" "plot [deviation] of user 2"
"user 3" 1.0 0 -15040220 true "" "plot [deviation] of user 3"
"" 1.0 2 -1664597 false "" "plot 0"

PLOT
960
496
1188
646
Inequality (GINI)
Round
NIL
0.0
14.0
0.0
1.0
true
true
"" ""
PENS
"inequality" 1.0 0 -8630108 true "" "plot gini"

MONITOR
1064
82
1193
127
Cooperation count
cooperationCount
17
1
11

SLIDER
15
340
197
373
confTrust_update_constant
confTrust_update_constant
0
1
0.07
0.01
1
NIL
HORIZONTAL

MONITOR
1065
131
1194
176
Round of depletion
time-of-depletion
17
1
11

MONITOR
973
131
1062
176
Depleted?
depleted
17
1
11

CHOOSER
14
264
197
309
init_knowledge_distr
init_knowledge_distr
"extreme-optimal-25-29" "weak-optimal-20-34" "largerRange-15-39" "completeRange-5-49" "underExpl-skewed-25-44" "overExpl-skewed-10-29"
3

SLIDER
14
383
196
416
deviationSensitivity
deviationSensitivity
0
1
0.333
0.01
1
NIL
HORIZONTAL

MONITOR
1065
35
1192
80
Overexploit count
overExploit_cnt
17
1
11

SLIDER
146
522
292
555
numInformed
numInformed
0
4
1
1
1
NIL
HORIZONTAL

TEXTBOX
16
493
455
533
Scenario experiments ----------------------------
16
105.0
1

CHOOSER
145
558
293
603
confInformed
confInformed
"high" "low"
0

SWITCH
15
523
129
556
experiment
experiment
1
1
-1000

MONITOR
972
82
1062
127
Cooperation?
cooperation
17
1
11

SLIDER
296
559
441
592
numUnInfSpeakHigh
numUnInfSpeakHigh
0
4
0
1
1
NIL
HORIZONTAL

SLIDER
296
522
441
555
numUnInfSpeakLow
numUnInfSpeakLow
0
4
0
1
1
NIL
HORIZONTAL

MONITOR
972
34
1063
79
Stock size
round(stockSizeBeforeGrowth)
17
1
11

@#$#@#$#@
_Note_ that you should see images within the following text. If they are not visible, make sure that the image files are placed in the same folder as the AgentEx.nlogo file.

## WHAT IS IT?

AgentEx aims to explain patterns observed in behavioural common pool-resource (CPR) laboratory experiments (Schill, Lindahl and Crépin 2015; Lindahl, Crépin and Schill 2016). In these experiments, groups that cooperate do not necessarily manage the shared resource sustainably, but also over- or underexploit (intentionally or unintentionally). Why does this happen? How can we explain these behaviours?

This model aims to provide answers to these questions and, thus, represents a possible explanation for the observed patterns. The explanation centers around the role of three individual-level variables (agent attributes): _social skills_ (i.e., the probability that the agent speaks up and shares its knowledge with the other agents), _individual knowledge_ (i.e., the agent’s perception of the optimal resource stock size) and _confidence in knowledge_, in addition to the in the literature ‘commonly’ used explanatory variables for cooperation: _trust_ and _social preferences_.

Like the experiment participants, over a number of rounds, the agents take individual decisions on how many resource units to extract from a shared renewable resource. The agents may communicate to agree on a group extraction level (i.e., they form a group knowledge) and then decide individually on the amount of resource units they will extract. Whether the agents decide to stick to the group’s agreement (i.e., cooperate) or not depends on three factors: 1) whether the individual extraction level is higher than the group extraction level, 2) their _social preferences_ (disposition to take equal shares) and 3) their _trust_ in others to follow the agreement.

## HOW IT WORKS

The model closely follows the structure and setup of the behavioural experiments: the agents represent the participants, the environment is represented by the same (abstract) renewable resource and a simulation run represent one behavioural experiment session, where each tick represents one of the 14 rounds in the behavioural experiments. After the initialisation (set-up), a cycle of eight processes (A-H) takes place every tick, visualised below and explained in the following paragraphs.
![alt text](file:Fig1_CycleS.png)

**A. Communicate-and-form-group-knowledge**
The group of agents may communicate and agree on a group extraction level (what they perceive as the optimal resource stock size). Communicating means sharing ones’ individual knowledge with the other agents. _Note_ that it is possible that some or all agents do not speak. Those who do not speak do not affect the formation of the group knowledge. If no one speaks, there is no group knowledge and - per definition - no cooperation. Whether an agent communicates or not depends only on its social skills, hence, independent from other group members’ actions. The higher the agent’s social skills, the higher the likelihood for it to communicate.

**B. Update-individual-knowledge**
The agents update their individual knowledge mainly based on what has been said (group knowledge), but there is always a small chance that the agent does not, or randomly, update its knowledge. The degree of update towards the group knowledge depends negatively on the agent’s confidence: the lower its confidence, the stronger the update. This reflects the possibility that individuals might not be or are differently affected by others. In case there is no communication, the level of confidence will determine whether the agent will update (randomly): the higher the confidence, the lower the likelihood that it randomly updates its knowledge.

**C. Calculate-individual-extraction-level**
Each agent decides on the amount of resource units it will extract based on its own knowledge (i.e., what it perceives to be the optimal stock size) and its social preferences. If the agent has social preferences, it will extract only its share from what it thinks is optimal to extract in total: max (0, (stock – individual-perceived-optimal-stock-size) / number-of-agents). Agents without social preferences might take out more (its share + random amount). _Note_ that the individual extraction level can be zero to allow the resource to recover.

**D. Calculate-group-extraction-level**
The group may form an agreement on how much to extract, i.e., the group extraction level based on group knowledge. It follows the same procedure as for the calculation of the individual extraction level (C) and is equally shared by all group members: max (0, (stock – group-perceived-optimal-stock-size) / number-of-agents). _Note_ that the extraction level can be zero to allow the resource to recover.

**E. Choose-extraction-level**
Each agent chooses between the individual or group extraction level. The figure below illustrates the decision tree. Firstly, the choice of the agent depends on whether the individual extraction level provides a higher payoff (more resource units to extract) than the group extraction level. The extraction level with the highest payoff is chosen, unless the agent has social preferences and high trust. More specifically, an agent with social preferences may choose the less profitable group extraction level if trust is high enough (a trust based probability). If all agents choose the group extraction level in a given round, the group cooperates.

![alt text](file:Fig2_Decision_treeS.png)

**F. Extract**
Agents extract the resource units according to their chosen extraction level in the process choose-extraction-level (E).

**G. Regrow-resource-stock**
The resource regenerates according to the resource dynamics illustrated in the figure below. It is a discrete version of a logistic growth function. There is a minimum resource stock size (5 units) necessary for regeneration to take place. The maximum resource stock size is 50 units (carrying capacity). The regeneration rate changes in steps of five units and the maximum sustainable yield is nine resource stock units.

![alt text](file:Fig3_regeneration_functionS.png)

**H. Update-confidence-trust**
Given the new stock size, each agent might update its confidence in knowledge and trust. This update depends on whether the new stock size deviates from what the agent expected it to be. If the stock size corresponds to what the agent expected, its trust and confidence increase. If the new stock size is larger than expected, confidence decreases, as the agent attributes this deviation to lack of knowledge. Trust does not change in that case since taking less than agreed is not considered to harm trust. If the new stock size is smaller than expected, both trust and confidence decrease, as the agent cannot be sure whether the deviation is due to someone having extracted more than agreed (other) or because of lack of knowledge (self). The magnitude of the trust and confidence update depends on the size of the deviation, i.e., the bigger the deviation, the stronger the in/decrease, and vice versa.

## HOW TO USE IT

In this section we describe how AgentEx’s interface works. All elements are grouped into one of the following three categories: Main actions, Setting up simulation experiments and Output.

### Main actions

**_set-up_**. Prepares the model for a simulation run; must be pressed before running the model.

**_go_**. Runs a simulation of 14 rounds.

**_step_**. Runs one round of the simulation.

###Setting up simulation experiments

The interface has several types of controls (buttons, switches, choosers, sliders) that allow for different experimental settings. We grouped these manipuation controls as follows:

> - **_Independent variables_**. With the choosers, these variables can be set differently to explore their effects. Their setting determines the characteristics of the group of agents as a whole. The individual agent attributes will be defined based on any given selection.
> - **_Control variables_**. These variables may impact the outcomes but are not part of the research questions we explored with AgentEx. They were calibrated and used as constants, however, one can vary them when asking different questions. Unless one explicitly wants to explore the effects of these variables, we recommend to set them as follows:
> -- confTrust_update_constant = 0.07
> -- groupKnowledgeFormation = weightedAverage
> -- deviationSensitivity = 0.333
> - **_Scenario experiments controls_**. Sets specific scenarios for simulation experiments in which the agents’ attribute composition (between and within agents) is controlled for, e.g., an agent that speaks, is confident but (initially) uninformed (i.e., perceived and actual optimal stock size do not coincide). We made use of these settings in Schill, Wijermans, Lindahl and Schlüter (2016).
> - **_autoRandomSeed_**. This switch defines whether the random seed is set manually or automatically. It should be switched off in case one wants to reproduce the exact same situation as well as controlling for the randomness to observe what is the effect of a particular variable (or set of variables).

The table below provides an overview of each variable with  support on what a certain  setting means.

![alt text](file:Fig4_overviewControls.png)

###Output

AgentEx's output is composed by the so-called view, plots and monitors. The view is a visual representation of AgentEx, whereas the plots and monitors show the outcome variables.

#### **View**.
The view displays four agents (users) sharing a resource (pond; the darker the colour, the more is left of the resource). Speaking agents are displayed with a dialogue bubble. The colour of the agents indicates their social preferences, whether they cooperate or not (in a given round) or knowledge dominance (the latter only if groupKnowledgeFormation is set to dominanceConfidence or dominanceSocialSkills). The **_MeaningOfUserColour_** chooser is used to select which agents’ attributes are reflected by the agents' colour {green,orange}:
- _colourSocialPreferences_: green  = agent has social preferences; orange = agent has no social preferences.
- _colourBehavior_: green = group level extraction is chosen; orange = individual level extraction is chosen.
- _colourDominance_: green = agent is the speaker with highest social skills (only when groupKnowledgeFormation is set to dominanceSocialSkills) or highest confidence (only when groupKnowledgeFormation is set to dominanceSocialSkills).

#### **Outcome variables**.

PLOTS:

**_Ind. vs. group extraction level_**. This plot shows the number of agents choosing either their individual (orange) or the group (green) extraction level in every round.

**_Resource stock size_**. This plot shows the variation in stock size (before regeneration) during a simulation run. The dotted lines indicate the optimal stock size interval.

**_Individual knowledge_**. This plot shows the variation of individual knowledge of each agent during a simulation run. The dotted lines indicate the optimal stock size interval.

**_Group knowledge_**. This plot shows the variation of group knowledge during a simulation run. The dotted lines indicate the optimal stock size interval. There will be no group knowledge curve if there are no speaking agents in the simulation run.

**_Trust_**. This plot shows the variation of trust of each agent during a simulation run.

**_Confidence in knowledge_**. This plot shows the variation of confidence in knowledge of each agent during a simulation run.

**_Deviation stock size_**. This plot shows the variation of how much the actual stock size deviates from each agent’s expected stock size during a simulation run.

**_Actual extraction_**. This plot shows the variation of each agent’s extraction of resource units along the simulation.

**_Accumulated extraction_**. This plot shows the variation of each agent’s actual extraction of resource units during a simulation run.

**_Inequality (GINI)_**. This plot shows the variation of inequality in resource extraction during a simulation run.

Please _note_, to know which agent in the View corresponds to which of the lines in the plots, you can right-click on the agents (be aware that numeration changes with every simulation run).

MONITORS:

**_Stock size_**. This monitor indicates the stock size (before regeneration) at the end of each round.

**_Overexploitation count_**. This monitor indicates the number of rounds the total extraction exceeds the optimal level.

**_Cooperation?_** This monitor shows ‘true’ when all the agents choose the group extraction level in any given round.

**_Cooperation count_**. This monitor indicates the number of rounds/ticks all four agents chose the group extraction level, i.e., cooperate.

**_Depletion?_** If the resource stock is depleted, this monitor displays 'true' until the end of the simulation tun, otherwise remains 'false'.

**_Round of depletion_**. In case of depletion, this monitor shows the number of round when it happened (1 – 14).

**_Number of speakers_**. This monitor indicates the number of speaking agents.

**_Group planned extraction_**. This monitor shows the group extraction level in any given round. The monitor will show a value of zero if there are no speakers.

## THINGS TO NOTICE

AgentEx has been built to simulate processes leading to cooperative or non-cooperative exploitation of a renewable and shared resource. Therefore, we suggest always paying attention to the following two plots: _Ind. vs. group extraction level_ and _Resource stock size_. Additionally, we suggest looking for relations between the outcome variables displayed on the plots. The most important relations are explained below, along with some insights about this model’s functioning. For further details, we suggest to turn to the ODD+D of AgentEx.

**Key behavioural patterns:** AgentEx is concerned with patterns of cooperation and exploitation (reflected in the resource stock size). The group of agents can cooperatively of non-cooperatively under-/over- or optimally exploit the resource. Each of these patterns are shown in the figures below.
![alt text](file:Fig5_cooperationPatterns.png)
- _Cooperation patterns_. (A) represents homogenous, constant cooperative behaviour (i.e., all agents chose in all 14 rounds the group extraction level), (B) represents homogenous, constant non-cooperative behaviour, (i.e., all agents chose in all 14 rounds the individual extraction level), and (C) represents heterogeneous non-/cooperative behaviour. The y-axis indicates the number of agents that choose the individual (orange) or group (green) extraction level.

![alt text](file:Fig6_exploitationPatterns.png)
- _Exploitation patterns._ (A) represents underexploitation (i.e., the resource stock size is above 29), (B) represents optimal exploitation (i.e., the resource stock size is between 25 and 29) and (C) represents overexploitation (i.e., the resource stock size is below 25).

**Key relation 1: Deviation stock size, trust and confidence in knowledge.** _Trust_ and _confidenceKnowledge_ change according to _deviation_. Deviation means how much the total extraction differs from the expected extraction. The plots below provide a clear example of this.
![alt text](file:Fig7_relationDevTrustConf.png)
- _Relation between deviation stock size (expected vs. actual stock size)_, trust and confidence in knowledge. (A) shows the development of trust over time for each of the four agents (users), (B) shows the development of confidence in knowledge over time for each of the four agents and (C) shows the deviation over time between expected and actual stock size for each agent. _Note_ that for user 2 (red), deviation is very low and infrequent, hence, trust and confidence in knowledge of user 2 increase in almost all rounds. In contrast, deviation for user 3 (green) is large and frequent in almost all rounds, hence, trust and confidence decrease strongly. _Note_ that there is only negative deviation in this example, i.e., the actual stock size was lower than expected. A positive deviation would only influence confidence in knowledge.

**Key relation 2: Trust and (non-) cooperation.** Cooperative behaviour increases _trust_, which in turn increases the likelihood of the agents to choose the group extraction level (cooperative behaviour), which feeds back to _trust_ - this is a reinforcing feedback, see figures below.
![alt text](file:Fig8_trustCoop_feedback.png)
- _Relation between trust and (non-) cooperation._ (A) shows for each round how many agents (users) choose the individual versus group extraction level. In rounds in which all users choose the group extraction level (green), the group cooperates. Cooperation leads to an increase in trust, as you can see in (B). For example, in round 2 all users choose the group extraction level. This leads to an increase of trust for all users. The higher the trust level, the more likely the user will choose the group extraction level in the following round. This can be seen in (B): once trust = 1 for all users, all agents cooperate.

## THINGS TO TRY

We provide you with some ideas of what you can try out with AgentEx. The first two ideas “Testing the effect of initial trust” and “Testing the importance of individual knowledge” are useful to start playing with the model and understanding both how it works and how to ask questions to it. Lastly, with the third idea “Tragedy of the commons scenario”, you can explore under which conditions a tragedy can be prevented in AgentEx.

###Testing the effect of initial trust.
Set the independent and control variables as indicated in the table below and turn off the random seed. Then create different scenarios by changing the value of the control variable _init trust distribution_. Pay attention to the effect on the plots _Ind. vs. group extraction level_ and _Resource stock size_.

> o	socialSkills_distribution = all_high
> o	socialPreferences_distribution = all
> o	init_confidenceKnowledge_distr = zero
> o	init_trust_distribution = zero (modify only this variable)
> o	init_knowledge_distr = completeRange-5-49
> o	confTrust_update_constant = 0.07
> o	groupKnowledgeFormation = weightedAverage
> o	deviationSensitivity = 0.333
> o	autoRandomSeed = off
> o	scenario experiments controls = off

###Testing the importance of individual knowledge.
Set the independent and control variables as indicated in the table below and turn off the random seed. Then create different knowledge scenarios by changing the value of the independent variable _init knowledge distr_. Pay attention to the effect on the outcome variable _Resource stock size_, you are trying to reach the optimal resource stock range between the grey dotted lines of the plot.

> o	socialSkills_distribution = all_high
> o	socialPreferences_distribution = all
> o	init_confidenceKnowledge_distr = zero
> o	init_trust_distribution = zero
> o	init_knowledge_distr = extreme-optimal-25-29 (modify this variable)
> o	confTrust_update_constant = 0.07
> o	groupKnowledgeFormation = weightedAverage
> o	deviationSensitivity = 0.333
> o	autoRandomSeed = off
> o	scenario experiments controls = off

###Tragedy of the commons scenario.
Hardin's (1968) "Tragedy of the commons" describes a situation in which a group of resource users sharing a resource inevitably overexploit it because it is each and everyones' personal interest to take as much as possible. However, there is growing evidence that the tragedy can be prevented. For example, trust and communication can thereby play a crucial role. Moreover, numerous experimental studies show that people do not always follow their self-interest but instead value, for example, fairness more than profit maximization. In order to explore which conditions create a "tragedy" and which facilitate cooperation and sustainable resource use in AgentEx, set the independent and control variables as indicated in the table below, turn off the random seed and play with the five different agent attributes. _Note_ setting _socialSkill distribution_ to 'zero' implies no communication.

> -	socialSkills_distribution = noone (modify this variable)
> -	socialPreferences_distribution = noone (modify this variable)
> -	init_confidenceKnowledge_distr = zero (modify this variable)
> -	init_trust_distribution = zero (modify this variable)
> -	init_knowledge_distr = completeRange-5-49 (modify this variable)
> -	confTrust_update_constant = 0.07
> -	groupKnowledgeFormation = weightedAverage
> -	deviationSensitivity = 0.333
> -	autoRandomSeed = off
> -	scenario experiments controls = off


## EXTENDING THE MODEL

###Increased duration extension
AgentEx sticks to the number of rounds Schill et al. (2015) and Lindahl et al. (2016) used in their behavioural experiments. Nevertheless, this model could be expanded for simulating runs longer than 14 ticks to explore what kind of scenarios lead to stable or unstable conditions in the long-term.

###Larger groups extension
AgentEx sticks to the number of participants Schill et al. (2015) and Lindahl et al. (2016) used in their behavioural experiments. Nevertheless, the model could be expanded for exploring how cooperative and non-cooperative behaviour is affected by group size.

###Ecological complexity extension
The ecological system is described fairly simple in the current version of AgentEx. For example, the resource dynamics are fairly “smooth” and there is no external environmental uncertainty. An interesting addition could be to allow for abrupt changes in the regeneration rate of the resource, as in the “threshold” treatment of Lindahl et al. (2016), see figure below.

![alt text](file:Fig9_ecologicalComplexityExtension.jpg)
Source: Figure 2 of Lindahl et al. (2016)

## CREDITS AND REFERENCES

The content of this infotab has been made with the help of Rodrigo Martinez.

**References: **
Hardin, G. (1968). The Tragedy of the Commons. Science 162(3859):1243–1248.

Lindahl, T., Crépin, A.-S. & C. Schill (2016). Potential disasters can turn the tragedy into success. Environmental and Resource Economics. First online. doi: 10.1007/s10640-016-0043-1.

Schill, C., Wijermans, N., Schlüter M. & T. Lindahl (2016). Cooperation Is Not Enough - Exploring Social-Ecological Micro-Foundations for Sustainable Common-Pool Resource Use. PLoS ONE 11(8): e0157796. doi:10.1371/journal.pone.0157796.

Schill, C., Lindahl, T. & A.-S. Crépin (2015). Collective action and the risk of ecosystem regime shifts: Insights from a laboratory experiment. Ecology and Society, 20(1). http://www.ecologyandsociety.org/vol20/iss1/art48/

## Feedback & Questions

If you have feedback about anything, we are very keen to hear about it!
Also, in case of questions: send an email to me (Nanda Wijermans): nanda.wijermans@su.se
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cooperator
false
0
Circle -1184463 false false 70 -20 160
Circle -1184463 false false 70 -20 160
Circle -1184463 false false 70 -20 160
Circle -7500403 true true 110 5 80
Rectangle -7500403 true true 127 79 172 94
Circle -1184463 false false 70 -20 160
Circle -1184463 false false 70 -20 160
Circle -1184463 false false 70 -20 160
Circle -1184463 false false 70 -20 160
Circle -1184463 false false 70 -20 160
Circle -1184463 false false 70 -20 160
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105
Polygon -14835848 true false 120 75 60 60 120 75 75 45

person farmer
false
0
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Polygon -1 true false 60 195 90 210 114 154 120 195 180 195 187 157 210 210 240 195 195 90 165 90 150 105 150 150 135 90 105 90
Circle -7500403 true true 110 5 80
Rectangle -7500403 true true 127 79 172 94
Polygon -13345367 true false 120 90 120 180 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 180 90 172 89 165 135 135 135 127 90
Polygon -6459832 true false 116 4 113 21 71 33 71 40 109 48 117 34 144 27 180 26 188 36 224 23 222 14 178 16 167 0
Line -16777216 false 225 90 270 90
Line -16777216 false 225 15 225 90
Line -16777216 false 270 15 270 90
Line -16777216 false 247 15 247 90
Rectangle -6459832 true false 240 90 255 300

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

sheep
false
15
Circle -1 true true 203 65 88
Circle -1 true true 70 65 162
Circle -1 true true 150 105 120
Polygon -7500403 true false 218 120 240 165 255 165 278 120
Circle -7500403 true false 214 72 67
Rectangle -1 true true 164 223 179 298
Polygon -1 true true 45 285 30 285 30 240 15 195 45 210
Circle -1 true true 3 83 150
Rectangle -1 true true 65 221 80 296
Polygon -1 true true 195 285 210 285 210 240 240 210 195 210
Polygon -7500403 true false 276 85 285 105 302 99 294 83
Polygon -7500403 true false 219 85 210 105 193 99 201 83

speaker
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105
Polygon -14835848 true false 120 75 60 60 120 75 75 45
Polygon -1 true false 75 45 120 75 75 60
Rectangle -1 true false 15 15 90 75

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

wolf
false
0
Polygon -16777216 true false 253 133 245 131 245 133
Polygon -7500403 true true 2 194 13 197 30 191 38 193 38 205 20 226 20 257 27 265 38 266 40 260 31 253 31 230 60 206 68 198 75 209 66 228 65 243 82 261 84 268 100 267 103 261 77 239 79 231 100 207 98 196 119 201 143 202 160 195 166 210 172 213 173 238 167 251 160 248 154 265 169 264 178 247 186 240 198 260 200 271 217 271 219 262 207 258 195 230 192 198 210 184 227 164 242 144 259 145 284 151 277 141 293 140 299 134 297 127 273 119 270 105
Polygon -7500403 true true -1 195 14 180 36 166 40 153 53 140 82 131 134 133 159 126 188 115 227 108 236 102 238 98 268 86 269 92 281 87 269 103 269 113

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270

@#$#@#$#@
NetLogo 5.3.1
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
<experiments>
  <experiment name="experiment_April2015" repetitions="500" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>coopPower</metric>
    <metric>gini</metric>
    <metric>meanStocksizeBG</metric>
    <metric>sdStocksizeBG</metric>
    <metric>medianStocksizeBG</metric>
    <metric>underExploit_cnt</metric>
    <metric>overExploit_cnt</metric>
    <metric>optimal_cnt</metric>
    <metric>meanEfficiency</metric>
    <metric>sdEfficiency</metric>
    <metric>medianEfficiency</metric>
    <metric>sumTotalExtraction</metric>
    <metric>meanTotalExtraction</metric>
    <metric>medianTotalExtraction</metric>
    <metric>sdTotalExtraction</metric>
    <metric>meanGroupKnowledge</metric>
    <metric>sdGroupKnowledge</metric>
    <metric>medianGroupKnowledge</metric>
    <metric>meanTrust</metric>
    <metric>sdTrust</metric>
    <metric>medianTrust</metric>
    <metric>numSpeakers</metric>
    <metric>time-of-depletion</metric>
    <metric>autoSeed</metric>
    <enumeratedValueSet variable="socialSkills_distribution">
      <value value="&quot;noone&quot;"/>
      <value value="&quot;all_high&quot;"/>
      <value value="&quot;all_low&quot;"/>
      <value value="&quot;75-0-25_lmh&quot;"/>
      <value value="&quot;25-0-75_lmh&quot;"/>
      <value value="&quot;50-0-50_lmh&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="socialPreference_distribution">
      <value value="&quot;all&quot;"/>
      <value value="&quot;75%&quot;"/>
      <value value="&quot;50%&quot;"/>
      <value value="&quot;25%&quot;"/>
      <value value="&quot;noone&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="init_trust_distribution">
      <value value="&quot;all_high&quot;"/>
      <value value="&quot;all_medium&quot;"/>
      <value value="&quot;all_low&quot;"/>
      <value value="&quot;75-0-25_lmh&quot;"/>
      <value value="&quot;50-0-50_lmh&quot;"/>
      <value value="&quot;25-0-75_lmh&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="init_confidenceKnowledge_distr">
      <value value="&quot;all_high&quot;"/>
      <value value="&quot;all_medium&quot;"/>
      <value value="&quot;all_low&quot;"/>
      <value value="&quot;75-0-25_lmh&quot;"/>
      <value value="&quot;50-0-50_lmh&quot;"/>
      <value value="&quot;25-0-75_lmh&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="init_knowledge_distr">
      <value value="&quot;completeRange-5-49&quot;"/>
      <value value="&quot;largerRange-15-39&quot;"/>
      <value value="&quot;extreme-optimal-25-29&quot;"/>
      <value value="&quot;weak-optimal-20-34&quot;"/>
      <value value="&quot;underExpl-skewed-25-44&quot;"/>
      <value value="&quot;overExpl-skewed-10-29&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="groupKnowledgeFormation">
      <value value="&quot;weightedAverage&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="updateIndividualKnowledge">
      <value value="&quot;gradual&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="confTrust_update_constant">
      <value value="0.07"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="deviationSensitivity">
      <value value="0.333"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="probIND">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="confidenceKnowledgeThreshold">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="meaningOfUserColour">
      <value value="&quot;colourSocialPreferences&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="autoRandomSeed">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="manualSeed">
      <value value="1"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="experiment_coopOverTime_Dec2015" repetitions="500" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>coopPower</metric>
    <metric>stockSizeBeforeGrowth</metric>
    <enumeratedValueSet variable="socialSkills_distribution">
      <value value="&quot;all_high&quot;"/>
      <value value="&quot;75-0-25_lmh&quot;"/>
      <value value="&quot;25-0-75_lmh&quot;"/>
      <value value="&quot;50-0-50_lmh&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="socialPreference_distribution">
      <value value="&quot;all&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="init_trust_distribution">
      <value value="&quot;all_high&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="init_confidenceKnowledge_distr">
      <value value="&quot;25-0-75_lmh&quot;"/>
      <value value="&quot;50-0-50_lmh&quot;"/>
      <value value="&quot;75-0-25_lmh&quot;"/>
      <value value="&quot;all_high&quot;"/>
      <value value="&quot;all_low&quot;"/>
      <value value="&quot;all_medium&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="init_knowledge_distr">
      <value value="&quot;completeRange-5-49&quot;"/>
      <value value="&quot;largerRange-15-39&quot;"/>
      <value value="&quot;extreme-optimal-25-29&quot;"/>
      <value value="&quot;weak-optimal-20-34&quot;"/>
      <value value="&quot;underExpl-skewed-25-44&quot;"/>
      <value value="&quot;overExpl-skewed-10-29&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="groupKnowledgeFormation">
      <value value="&quot;weightedAverage&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="updateIndividualKnowledge">
      <value value="&quot;gradual&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="learningRate">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="confTrust_update_constant">
      <value value="0.07"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="deviationSensitivity">
      <value value="0.333"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="probIND">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="confidenceKnowledgeThreshold">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="meaningOfUserColour">
      <value value="&quot;colourSocialPreferences&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="autoRandomSeed">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="manualSeed">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Experiment">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="scenario1_overTime_scen4SpBase" repetitions="5000" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>cooperation</metric>
    <metric>gini</metric>
    <metric>stockSizeBeforeGrowth</metric>
    <metric>totalExtraction</metric>
    <metric>optimal</metric>
    <metric>overExpl</metric>
    <metric>underExpl</metric>
    <metric>optimal_cnt</metric>
    <metric>overExploit_cnt</metric>
    <metric>underExploit_cnt</metric>
    <metric>efficiency</metric>
    <metric>groupKnowledge</metric>
    <metric>meanTrust</metric>
    <metric>sdTrust</metric>
    <metric>medianTrust</metric>
    <metric>[trust] of user 0</metric>
    <metric>[trust] of user 1</metric>
    <metric>[trust] of user 2</metric>
    <metric>[trust] of user 3</metric>
    <metric>meanConfidence</metric>
    <metric>sdConfidence</metric>
    <metric>medianConfidence</metric>
    <metric>[confidenceKnowledge] of user 0</metric>
    <metric>[confidenceKnowledge] of user 1</metric>
    <metric>[confidenceKnowledge] of user 2</metric>
    <metric>[confidenceKnowledge] of user 3</metric>
    <metric>meanIndKnow</metric>
    <metric>sdIndKnow</metric>
    <metric>medianIndKnow</metric>
    <metric>[individualKnowledge] of user 0</metric>
    <metric>[individualKnowledge] of user 1</metric>
    <metric>[individualKnowledge] of user 2</metric>
    <metric>[individualKnowledge] of user 3</metric>
    <metric>numSpeakers</metric>
    <metric>autoSeed</metric>
    <enumeratedValueSet variable="numInformed">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="numUnInfSpeakHigh">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="numUnInfSpeakLow">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="confInformed">
      <value value="&quot;high&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="groupKnowledgeFormation">
      <value value="&quot;weightedAverage&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="updateIndividualKnowledge">
      <value value="&quot;gradual&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="learningRate">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="confTrust_update_constant">
      <value value="0.07"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="deviationSensitivity">
      <value value="0.333"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="probIND">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="confidenceKnowledgeThreshold">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="meaningOfUserColour">
      <value value="&quot;colourSocialPreferences&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="autoRandomSeed">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="manualSeed">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Experiment">
      <value value="true"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="scenario2_overTime_scen4SpB" repetitions="5000" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>cooperation</metric>
    <metric>gini</metric>
    <metric>stockSizeBeforeGrowth</metric>
    <metric>totalExtraction</metric>
    <metric>optimal</metric>
    <metric>overExpl</metric>
    <metric>underExpl</metric>
    <metric>optimal_cnt</metric>
    <metric>overExploit_cnt</metric>
    <metric>underExploit_cnt</metric>
    <metric>efficiency</metric>
    <metric>groupKnowledge</metric>
    <metric>meanTrust</metric>
    <metric>sdTrust</metric>
    <metric>medianTrust</metric>
    <metric>[trust] of user 0</metric>
    <metric>[trust] of user 1</metric>
    <metric>[trust] of user 2</metric>
    <metric>[trust] of user 3</metric>
    <metric>meanConfidence</metric>
    <metric>sdConfidence</metric>
    <metric>medianConfidence</metric>
    <metric>[confidenceKnowledge] of user 0</metric>
    <metric>[confidenceKnowledge] of user 1</metric>
    <metric>[confidenceKnowledge] of user 2</metric>
    <metric>[confidenceKnowledge] of user 3</metric>
    <metric>meanIndKnow</metric>
    <metric>sdIndKnow</metric>
    <metric>medianIndKnow</metric>
    <metric>[individualKnowledge] of user 0</metric>
    <metric>[individualKnowledge] of user 1</metric>
    <metric>[individualKnowledge] of user 2</metric>
    <metric>[individualKnowledge] of user 3</metric>
    <metric>numSpeakers</metric>
    <metric>autoSeed</metric>
    <enumeratedValueSet variable="numInformed">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="numUnInfSpeakHigh">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="numUnInfSpeakLow">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="confInformed">
      <value value="&quot;high&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="groupKnowledgeFormation">
      <value value="&quot;weightedAverage&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="updateIndividualKnowledge">
      <value value="&quot;gradual&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="learningRate">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="confTrust_update_constant">
      <value value="0.07"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="deviationSensitivity">
      <value value="0.333"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="probIND">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="confidenceKnowledgeThreshold">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="meaningOfUserColour">
      <value value="&quot;colourSocialPreferences&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="autoRandomSeed">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="manualSeed">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Experiment">
      <value value="true"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="scenario6_overTime_scen2SpB" repetitions="5000" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>cooperation</metric>
    <metric>gini</metric>
    <metric>stockSizeBeforeGrowth</metric>
    <metric>totalExtraction</metric>
    <metric>optimal</metric>
    <metric>overExpl</metric>
    <metric>underExpl</metric>
    <metric>optimal_cnt</metric>
    <metric>overExploit_cnt</metric>
    <metric>underExploit_cnt</metric>
    <metric>efficiency</metric>
    <metric>groupKnowledge</metric>
    <metric>meanTrust</metric>
    <metric>sdTrust</metric>
    <metric>medianTrust</metric>
    <metric>[trust] of user 0</metric>
    <metric>[trust] of user 1</metric>
    <metric>[trust] of user 2</metric>
    <metric>[trust] of user 3</metric>
    <metric>meanConfidence</metric>
    <metric>sdConfidence</metric>
    <metric>medianConfidence</metric>
    <metric>[confidenceKnowledge] of user 0</metric>
    <metric>[confidenceKnowledge] of user 1</metric>
    <metric>[confidenceKnowledge] of user 2</metric>
    <metric>[confidenceKnowledge] of user 3</metric>
    <metric>meanIndKnow</metric>
    <metric>sdIndKnow</metric>
    <metric>medianIndKnow</metric>
    <metric>[individualKnowledge] of user 0</metric>
    <metric>[individualKnowledge] of user 1</metric>
    <metric>[individualKnowledge] of user 2</metric>
    <metric>[individualKnowledge] of user 3</metric>
    <metric>numSpeakers</metric>
    <metric>autoSeed</metric>
    <enumeratedValueSet variable="numInformed">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="numUnInfSpeakHigh">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="numUnInfSpeakLow">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="confInformed">
      <value value="&quot;high&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="groupKnowledgeFormation">
      <value value="&quot;weightedAverage&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="updateIndividualKnowledge">
      <value value="&quot;gradual&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="learningRate">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="confTrust_update_constant">
      <value value="0.07"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="deviationSensitivity">
      <value value="0.333"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="probIND">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="confidenceKnowledgeThreshold">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="meaningOfUserColour">
      <value value="&quot;colourSocialPreferences&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="autoRandomSeed">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="manualSeed">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Experiment">
      <value value="true"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="scenario7_overTime_scen2SpD" repetitions="5000" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>cooperation</metric>
    <metric>gini</metric>
    <metric>stockSizeBeforeGrowth</metric>
    <metric>totalExtraction</metric>
    <metric>optimal</metric>
    <metric>overExpl</metric>
    <metric>underExpl</metric>
    <metric>optimal_cnt</metric>
    <metric>overExploit_cnt</metric>
    <metric>underExploit_cnt</metric>
    <metric>efficiency</metric>
    <metric>groupKnowledge</metric>
    <metric>meanTrust</metric>
    <metric>sdTrust</metric>
    <metric>medianTrust</metric>
    <metric>[trust] of user 0</metric>
    <metric>[trust] of user 1</metric>
    <metric>[trust] of user 2</metric>
    <metric>[trust] of user 3</metric>
    <metric>meanConfidence</metric>
    <metric>sdConfidence</metric>
    <metric>medianConfidence</metric>
    <metric>[confidenceKnowledge] of user 0</metric>
    <metric>[confidenceKnowledge] of user 1</metric>
    <metric>[confidenceKnowledge] of user 2</metric>
    <metric>[confidenceKnowledge] of user 3</metric>
    <metric>meanIndKnow</metric>
    <metric>sdIndKnow</metric>
    <metric>medianIndKnow</metric>
    <metric>[individualKnowledge] of user 0</metric>
    <metric>[individualKnowledge] of user 1</metric>
    <metric>[individualKnowledge] of user 2</metric>
    <metric>[individualKnowledge] of user 3</metric>
    <metric>numSpeakers</metric>
    <metric>autoSeed</metric>
    <enumeratedValueSet variable="numInformed">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="numUnInfSpeakHigh">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="numUnInfSpeakLow">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="confInformed">
      <value value="&quot;low&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="groupKnowledgeFormation">
      <value value="&quot;weightedAverage&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="updateIndividualKnowledge">
      <value value="&quot;gradual&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="learningRate">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="confTrust_update_constant">
      <value value="0.07"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="deviationSensitivity">
      <value value="0.333"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="probIND">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="confidenceKnowledgeThreshold">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="meaningOfUserColour">
      <value value="&quot;colourSocialPreferences&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="autoRandomSeed">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="manualSeed">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Experiment">
      <value value="true"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="scenario5_overTime_scen2SpA" repetitions="5000" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>cooperation</metric>
    <metric>gini</metric>
    <metric>stockSizeBeforeGrowth</metric>
    <metric>totalExtraction</metric>
    <metric>optimal</metric>
    <metric>overExpl</metric>
    <metric>underExpl</metric>
    <metric>optimal_cnt</metric>
    <metric>overExploit_cnt</metric>
    <metric>underExploit_cnt</metric>
    <metric>efficiency</metric>
    <metric>groupKnowledge</metric>
    <metric>meanTrust</metric>
    <metric>sdTrust</metric>
    <metric>medianTrust</metric>
    <metric>[trust] of user 0</metric>
    <metric>[trust] of user 1</metric>
    <metric>[trust] of user 2</metric>
    <metric>[trust] of user 3</metric>
    <metric>meanConfidence</metric>
    <metric>sdConfidence</metric>
    <metric>medianConfidence</metric>
    <metric>[confidenceKnowledge] of user 0</metric>
    <metric>[confidenceKnowledge] of user 1</metric>
    <metric>[confidenceKnowledge] of user 2</metric>
    <metric>[confidenceKnowledge] of user 3</metric>
    <metric>meanIndKnow</metric>
    <metric>sdIndKnow</metric>
    <metric>medianIndKnow</metric>
    <metric>[individualKnowledge] of user 0</metric>
    <metric>[individualKnowledge] of user 1</metric>
    <metric>[individualKnowledge] of user 2</metric>
    <metric>[individualKnowledge] of user 3</metric>
    <metric>numSpeakers</metric>
    <metric>autoSeed</metric>
    <enumeratedValueSet variable="numInformed">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="numUnInfSpeakHigh">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="numUnInfSpeakLow">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="confInformed">
      <value value="&quot;high&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="groupKnowledgeFormation">
      <value value="&quot;weightedAverage&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="updateIndividualKnowledge">
      <value value="&quot;gradual&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="learningRate">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="confTrust_update_constant">
      <value value="0.07"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="deviationSensitivity">
      <value value="0.333"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="probIND">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="confidenceKnowledgeThreshold">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="meaningOfUserColour">
      <value value="&quot;colourSocialPreferences&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="autoRandomSeed">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="manualSeed">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Experiment">
      <value value="true"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="scenario4_overTime_scen1SpBase" repetitions="5000" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>cooperation</metric>
    <metric>gini</metric>
    <metric>stockSizeBeforeGrowth</metric>
    <metric>totalExtraction</metric>
    <metric>optimal</metric>
    <metric>overExpl</metric>
    <metric>underExpl</metric>
    <metric>optimal_cnt</metric>
    <metric>overExploit_cnt</metric>
    <metric>underExploit_cnt</metric>
    <metric>efficiency</metric>
    <metric>groupKnowledge</metric>
    <metric>meanTrust</metric>
    <metric>sdTrust</metric>
    <metric>medianTrust</metric>
    <metric>[trust] of user 0</metric>
    <metric>[trust] of user 1</metric>
    <metric>[trust] of user 2</metric>
    <metric>[trust] of user 3</metric>
    <metric>meanConfidence</metric>
    <metric>sdConfidence</metric>
    <metric>medianConfidence</metric>
    <metric>[confidenceKnowledge] of user 0</metric>
    <metric>[confidenceKnowledge] of user 1</metric>
    <metric>[confidenceKnowledge] of user 2</metric>
    <metric>[confidenceKnowledge] of user 3</metric>
    <metric>meanIndKnow</metric>
    <metric>sdIndKnow</metric>
    <metric>medianIndKnow</metric>
    <metric>[individualKnowledge] of user 0</metric>
    <metric>[individualKnowledge] of user 1</metric>
    <metric>[individualKnowledge] of user 2</metric>
    <metric>[individualKnowledge] of user 3</metric>
    <metric>numSpeakers</metric>
    <metric>autoSeed</metric>
    <enumeratedValueSet variable="numInformed">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="numUnInfSpeakHigh">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="numUnInfSpeakLow">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="confInformed">
      <value value="&quot;high&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="groupKnowledgeFormation">
      <value value="&quot;weightedAverage&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="updateIndividualKnowledge">
      <value value="&quot;gradual&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="learningRate">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="confTrust_update_constant">
      <value value="0.07"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="deviationSensitivity">
      <value value="0.333"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="probIND">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="confidenceKnowledgeThreshold">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="meaningOfUserColour">
      <value value="&quot;colourSocialPreferences&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="autoRandomSeed">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="manualSeed">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Experiment">
      <value value="true"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="scenario3_overTime_scen4SpA" repetitions="5000" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>cooperation</metric>
    <metric>gini</metric>
    <metric>stockSizeBeforeGrowth</metric>
    <metric>totalExtraction</metric>
    <metric>optimal</metric>
    <metric>overExpl</metric>
    <metric>underExpl</metric>
    <metric>optimal_cnt</metric>
    <metric>overExploit_cnt</metric>
    <metric>underExploit_cnt</metric>
    <metric>efficiency</metric>
    <metric>groupKnowledge</metric>
    <metric>meanTrust</metric>
    <metric>sdTrust</metric>
    <metric>medianTrust</metric>
    <metric>[trust] of user 0</metric>
    <metric>[trust] of user 1</metric>
    <metric>[trust] of user 2</metric>
    <metric>[trust] of user 3</metric>
    <metric>meanConfidence</metric>
    <metric>sdConfidence</metric>
    <metric>medianConfidence</metric>
    <metric>[confidenceKnowledge] of user 0</metric>
    <metric>[confidenceKnowledge] of user 1</metric>
    <metric>[confidenceKnowledge] of user 2</metric>
    <metric>[confidenceKnowledge] of user 3</metric>
    <metric>meanIndKnow</metric>
    <metric>sdIndKnow</metric>
    <metric>medianIndKnow</metric>
    <metric>[individualKnowledge] of user 0</metric>
    <metric>[individualKnowledge] of user 1</metric>
    <metric>[individualKnowledge] of user 2</metric>
    <metric>[individualKnowledge] of user 3</metric>
    <metric>numSpeakers</metric>
    <metric>autoSeed</metric>
    <enumeratedValueSet variable="numInformed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="numUnInfSpeakHigh">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="numUnInfSpeakLow">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="confInformed">
      <value value="&quot;high&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="groupKnowledgeFormation">
      <value value="&quot;weightedAverage&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="updateIndividualKnowledge">
      <value value="&quot;gradual&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="learningRate">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="confTrust_update_constant">
      <value value="0.07"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="deviationSensitivity">
      <value value="0.333"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="probIND">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="confidenceKnowledgeThreshold">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="meaningOfUserColour">
      <value value="&quot;colourSocialPreferences&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="autoRandomSeed">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="manualSeed">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Experiment">
      <value value="true"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="experiment_April2015-overTime" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>coopPower</metric>
    <metric>stockSizeBeforeGrowth</metric>
    <enumeratedValueSet variable="socialSkills_distribution">
      <value value="&quot;noone&quot;"/>
      <value value="&quot;all_high&quot;"/>
      <value value="&quot;all_low&quot;"/>
      <value value="&quot;75-0-25_lmh&quot;"/>
      <value value="&quot;25-0-75_lmh&quot;"/>
      <value value="&quot;50-0-50_lmh&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="socialPreference_distribution">
      <value value="&quot;all&quot;"/>
      <value value="&quot;75%&quot;"/>
      <value value="&quot;50%&quot;"/>
      <value value="&quot;25%&quot;"/>
      <value value="&quot;noone&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="init_trust_distribution">
      <value value="&quot;all_high&quot;"/>
      <value value="&quot;all_medium&quot;"/>
      <value value="&quot;all_low&quot;"/>
      <value value="&quot;75-0-25_lmh&quot;"/>
      <value value="&quot;50-0-50_lmh&quot;"/>
      <value value="&quot;25-0-75_lmh&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="init_confidenceKnowledge_distr">
      <value value="&quot;all_high&quot;"/>
      <value value="&quot;all_medium&quot;"/>
      <value value="&quot;all_low&quot;"/>
      <value value="&quot;75-0-25_lmh&quot;"/>
      <value value="&quot;50-0-50_lmh&quot;"/>
      <value value="&quot;25-0-75_lmh&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="init_knowledge_distr">
      <value value="&quot;completeRange-5-49&quot;"/>
      <value value="&quot;largerRange-15-39&quot;"/>
      <value value="&quot;extreme-optimal-25-29&quot;"/>
      <value value="&quot;weak-optimal-20-34&quot;"/>
      <value value="&quot;underExpl-skewed-25-44&quot;"/>
      <value value="&quot;overExpl-skewed-10-29&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="groupKnowledgeFormation">
      <value value="&quot;weightedAverage&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="updateIndividualKnowledge">
      <value value="&quot;gradual&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="confTrust_update_constant">
      <value value="0.07"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="deviationSensitivity">
      <value value="0.333"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="probIND">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="confidenceKnowledgeThreshold">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="meaningOfUserColour">
      <value value="&quot;colourSocialPreferences&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="autoRandomSeed">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="manualSeed">
      <value value="1"/>
    </enumeratedValueSet>
  </experiment>
</experiments>
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180

@#$#@#$#@
0
@#$#@#$#@
